<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Juju Blog Pro
 * @since Juju Blog Pro 1.0.0
 */

if ( ! function_exists( 'juju_blog_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Juju Blog Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function juju_blog_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'juju_blog_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'juju_blog_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Juju Blog Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function juju_blog_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'juju_blog_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'juju_blog_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Juju Blog Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function juju_blog_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'juju_blog_pro_theme_options[pagination_enable]' )->value();
	}
endif;

if ( ! function_exists( 'juju_blog_pro_is_static_homepage_enable' ) ) :
	/**
	 * Check if static homepage is enabled.
	 *
	 * @since Juju Blog Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function juju_blog_pro_is_static_homepage_enable( $control ) {
		return ( 'page' == $control->manager->get_setting( 'show_on_front' )->value() );
	}
endif;

/**
 * Front Page Active Callbacks
 */

/*=====================top_bar================*/
/**
 * Check if top_bar section is enabled.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_top_bar_section_enable( $control ) {
	return ( $control->manager->get_setting( 'juju_blog_pro_theme_options[top_bar_section_enable]' )->value() );
}

/*========================slider====================*/

/**
 * Check if slider section is enabled.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_slider_section_enable( $control ) {

	return $control->manager->get_setting( 'juju_blog_pro_theme_options[slider_section_enable]' )->value() ;
}

/**
 * Check if slider section content type is category.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[slider_content_type]' )->value();
	return juju_blog_pro_is_slider_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if slider section content type is page.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[slider_content_type]' )->value();
	return juju_blog_pro_is_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if slider section content type is post.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[slider_content_type]' )->value();
	return juju_blog_pro_is_slider_section_enable( $control ) && ( 'post' == $content_type );
}

/*========================topics====================*/

/**
 * Check if topics section is enabled.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_topics_section_enable( $control ) {

	return $control->manager->get_setting( 'juju_blog_pro_theme_options[topics_section_enable]' )->value() ;
}

/**
 * Check if topics section content type is category.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_topics_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[topics_content_type]' )->value();
	return juju_blog_pro_is_topics_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if topics section content type is page.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_topics_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[topics_content_type]' )->value();
	return juju_blog_pro_is_topics_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if topics section content type is post.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_topics_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[topics_content_type]' )->value();
	return juju_blog_pro_is_topics_section_enable( $control ) && ( 'post' == $content_type );
}

/*========================stories====================*/

/**
 * Check if stories section is enabled.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_stories_section_enable( $control ) {

	return $control->manager->get_setting( 'juju_blog_pro_theme_options[stories_section_enable]' )->value() ;
}

/*=========================Recent Posts==================*/

/**
 * Check if recent_posts section is enabled.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_recent_posts_section_enable( $control ) {
	return ( $control->manager->get_setting( 'juju_blog_pro_theme_options[recent_posts_section_enable]' )->value() );
}

/**
 * Check if recent_posts section content type is category.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_recent_posts_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[recent_posts_content_type]' )->value();
	return juju_blog_pro_is_recent_posts_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if recent_posts section content type is page.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_recent_posts_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[recent_posts_content_type]' )->value();
	return juju_blog_pro_is_recent_posts_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if recent_posts section content type is post.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_recent_posts_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[recent_posts_content_type]' )->value();
	return juju_blog_pro_is_recent_posts_section_enable( $control ) && ( 'post' == $content_type );
}

/*========================most_read====================*/

/**
 * Check if most_read section is enabled.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_most_read_section_enable( $control ) {

	return $control->manager->get_setting( 'juju_blog_pro_theme_options[most_read_section_enable]' )->value() ;
}

/**
 * Check if most_read section content type is category.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_most_read_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[most_read_content_type]' )->value();
	return juju_blog_pro_is_most_read_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if most_read section content type is page.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_most_read_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[most_read_content_type]' )->value();
	return juju_blog_pro_is_most_read_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if most_read section content type is post.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_most_read_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[most_read_content_type]' )->value();
	return juju_blog_pro_is_most_read_section_enable( $control ) && ( 'post' == $content_type );
}

/*=======================subscription=========================*/

function juju_blog_pro_is_subscription_section_enable( $control ) {
	return $control->manager->get_setting( 'juju_blog_pro_theme_options[subscription_section_enable]' )->value();
}

/*=======================instagram=========================*/

function juju_blog_pro_is_instagram_section_enable( $control ) {
	return $control->manager->get_setting( 'juju_blog_pro_theme_options[instagram_section_enable]' )->value();
}

/*=======================top destination=========================*/

/**
 * Check if top destination section is enabled.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_top_destination_section_enable( $control ) {
	return ( $control->manager->get_setting( 'juju_blog_pro_theme_options[top_destination_section_enable]' )->value() );
}

/**
 * Check if top destination section content type is page.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_top_destination_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[top_destination_content_type]' )->value();
	return juju_blog_pro_is_top_destination_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if top destination section content type is post.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_top_destination_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[top_destination_content_type]' )->value();
	return juju_blog_pro_is_top_destination_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if top destination section content type is trip.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_top_destination_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[top_destination_content_type]' )->value();
	return juju_blog_pro_is_top_destination_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if top destination section content type is category.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_top_destination_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[top_destination_content_type]' )->value();
	return juju_blog_pro_is_top_destination_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if top destination section content type is trip types.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_top_destination_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[top_destination_content_type]' )->value();
	return juju_blog_pro_is_top_destination_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if top destination section content type is destination.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_top_destination_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[top_destination_content_type]' )->value();
	return juju_blog_pro_is_top_destination_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if top destination section content type is activity.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_top_destination_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[top_destination_content_type]' )->value();
	return juju_blog_pro_is_top_destination_section_enable( $control ) && ( 'activity' == $content_type );
}

/*=======================gallery=========================*/

/**
 * Check if gallery section is enabled.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_gallery_section_enable( $control ) {
	return ( $control->manager->get_setting( 'juju_blog_pro_theme_options[gallery_section_enable]' )->value() );
}

/**
 * Check if gallery section content type is page.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_gallery_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[gallery_content_type]' )->value();
	return juju_blog_pro_is_gallery_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if gallery section content type is post.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_gallery_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[gallery_content_type]' )->value();
	return juju_blog_pro_is_gallery_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if gallery section content type is trip.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_gallery_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[gallery_content_type]' )->value();
	return juju_blog_pro_is_gallery_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if gallery section content type is category.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_gallery_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[gallery_content_type]' )->value();
	return juju_blog_pro_is_gallery_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if gallery section content type is trip types.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_gallery_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[gallery_content_type]' )->value();
	return juju_blog_pro_is_gallery_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if gallery section content type is destination.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_gallery_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[gallery_content_type]' )->value();
	return juju_blog_pro_is_gallery_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if gallery section content type is activity.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_gallery_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[gallery_content_type]' )->value();
	return juju_blog_pro_is_gallery_section_enable( $control ) && ( 'activity' == $content_type );
}

/*========================event_slider====================*/

/**
 * Check if event_slider section is enabled.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_event_slider_section_enable( $control ) {

	return $control->manager->get_setting( 'juju_blog_pro_theme_options[event_slider_section_enable]' )->value() ;
}

/**
 * Check if event_slider section content type is category.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_event_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[event_slider_content_type]' )->value();
	return juju_blog_pro_is_event_slider_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if event_slider section content type is page.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_event_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[event_slider_content_type]' )->value();
	return juju_blog_pro_is_event_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if event_slider section content type is post.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_event_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[event_slider_content_type]' )->value();
	return juju_blog_pro_is_event_slider_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if event section content type is event.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_event_slider_section_content_event_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[event_slider_content_type]' )->value();
	return juju_blog_pro_is_event_slider_section_enable( $control ) && ( 'event' == $content_type );
}

/**
 * Check if event section content type is event category.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_event_slider_section_content_event_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[event_slider_content_type]' )->value();
	return juju_blog_pro_is_event_slider_section_enable( $control ) && ( 'event-category' == $content_type );
}

/*===========================service==================*/

/**
 * Check if service section is enabled.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_playlist_section_enable( $control ) {

	return $control->manager->get_setting( 'juju_blog_pro_theme_options[playlist_section_enable]' )->value() ;
}

/*===========================upcomming event==================*/

/**
 * Check if event section is enabled.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_upcomming_event_section_enable( $control ) {
	return ( $control->manager->get_setting( 'juju_blog_pro_theme_options[upcomming_event_section_enable]' )->value() );
}

/**
 * Check if event section content type is post.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_upcomming_event_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[upcomming_event_content_type]' )->value();
	return juju_blog_pro_is_upcomming_event_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if event section content type is page.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_upcomming_event_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[upcomming_event_content_type]' )->value();
	return juju_blog_pro_is_upcomming_event_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if event section content type is category.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_upcomming_event_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[upcomming_event_content_type]' )->value();
	return juju_blog_pro_is_upcomming_event_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if event section content type is event.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_upcomming_event_section_content_upcomming_event_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[upcomming_event_content_type]' )->value();
	return juju_blog_pro_is_upcomming_event_section_enable( $control ) && ( 'event' == $content_type );
}

/**
 * Check if event section content type is event category.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_upcomming_event_section_content_upcomming_event_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[upcomming_event_content_type]' )->value();
	return juju_blog_pro_is_upcomming_event_section_enable( $control ) && ( 'event-category' == $content_type );
}

/*=======================team====================*/
/**
 * Check if team section is enabled.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_team_section_enable( $control ) {
	return ( $control->manager->get_setting( 'juju_blog_pro_theme_options[team_section_enable]' )->value() );
}

/**
 * Check if team section content type is post.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_team_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[team_content_type]' )->value();
	return juju_blog_pro_is_team_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if team section content type is page.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_team_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[team_content_type]' )->value();
	return juju_blog_pro_is_team_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if team section content type is category.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_team_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[team_content_type]' )->value();
	return juju_blog_pro_is_team_section_enable( $control ) && ( 'category' == $content_type );
}

/*========================music_gallery====================*/

/**
 * Check if music_gallery section is enabled.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_music_gallery_section_enable( $control ) {

	return $control->manager->get_setting( 'juju_blog_pro_theme_options[music_gallery_section_enable]' )->value() ;
}

/**
 * Check if music_gallery section content type is category.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_music_gallery_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[music_gallery_content_type]' )->value();
	return juju_blog_pro_is_music_gallery_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if music_gallery section content type is page.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_music_gallery_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[music_gallery_content_type]' )->value();
	return juju_blog_pro_is_music_gallery_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if music_gallery section content type is post.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_music_gallery_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[music_gallery_content_type]' )->value();
	return juju_blog_pro_is_music_gallery_section_enable( $control ) && ( 'post' == $content_type );
}

/*========================Counter====================*/

/**
 * Check if counter section is enabled.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_counter_section_enable( $control ) {

	return $control->manager->get_setting( 'juju_blog_pro_theme_options[counter_section_enable]' )->value() ;
}

/*========================Sponsor====================*/

/**
 * Check if sponsor section is enabled.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_sponsor_section_enable( $control ) {

	return $control->manager->get_setting( 'juju_blog_pro_theme_options[sponsor_section_enable]' )->value() ;
}

/*========================blog_events====================*/

/**
 * Check if blog_events section is enabled.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_blog_events_section_enable( $control ) {

	return $control->manager->get_setting( 'juju_blog_pro_theme_options[blog_events_section_enable]' )->value() ;
}

/**
 * Check if blog_events section content type is category.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_blog_events_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[blog_events_content_type]' )->value();
	return juju_blog_pro_is_blog_events_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog_events section content type is page.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_blog_events_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[blog_events_content_type]' )->value();
	return juju_blog_pro_is_blog_events_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog_events section content type is post.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_blog_events_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[blog_events_content_type]' )->value();
	return juju_blog_pro_is_blog_events_section_enable( $control ) && ( 'post' == $content_type );
}

/*========================special_events====================*/

/**
 * Check if special_events section is enabled.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_special_events_section_enable( $control ) {

	return $control->manager->get_setting( 'juju_blog_pro_theme_options[special_events_section_enable]' )->value() ;
}

/**
 * Check if special_events section content type is category.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_special_events_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[special_events_content_type]' )->value();
	return juju_blog_pro_is_special_events_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if special_events section content type is page.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_special_events_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[special_events_content_type]' )->value();
	return juju_blog_pro_is_special_events_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if special_events section content type is post.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_special_events_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[special_events_content_type]' )->value();
	return juju_blog_pro_is_special_events_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if event section content type is event.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_special_events_section_content_special_events_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[special_events_content_type]' )->value();
	return juju_blog_pro_is_special_events_section_enable( $control ) && ( 'event' == $content_type );
}

/**
 * Check if event section content type is event category.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_special_events_section_content_special_events_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[special_events_content_type]' )->value();
	return juju_blog_pro_is_special_events_section_enable( $control ) && ( 'event-category' == $content_type );
}

/*===========================service==================*/

/**
 * Check if service section is enabled.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_service_section_enable( $control ) {

	return $control->manager->get_setting( 'juju_blog_pro_theme_options[service_section_enable]' )->value() ;
}

/**
 * Check if service section content type is category.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_service_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[service_content_type]' )->value();
	return juju_blog_pro_is_service_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if service section content type is page.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_service_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[service_content_type]' )->value();
	return juju_blog_pro_is_service_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if service section content type is post.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_service_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[service_content_type]' )->value();
	return juju_blog_pro_is_service_section_enable( $control ) && ( 'post' == $content_type );
}

/*=======================testimonial=========================*/
/**
 * Check if testimonial section is enabled.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_testimonial_section_enable( $control ) {
	return ( $control->manager->get_setting( 'juju_blog_pro_theme_options[testimonial_section_enable]' )->value() );
}

/**
 * Check if testimonial section content type is page.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_testimonial_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[testimonial_content_type]' )->value();
	return juju_blog_pro_is_testimonial_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if testimonial section content type is post.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_testimonial_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[testimonial_content_type]' )->value();
	return juju_blog_pro_is_testimonial_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if testimonial section content type is category.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_testimonial_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[testimonial_content_type]' )->value();
	return juju_blog_pro_is_testimonial_section_enable( $control ) && ( 'category' == $content_type );
}

/*=======================about=====================*/
/**
 * Check if about section is enabled.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_about_section_enable( $control ) {
	return ( $control->manager->get_setting( 'juju_blog_pro_theme_options[about_section_enable]' )->value() );
}

/**
 * Check if about section content type is page.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_about_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[about_content_type]' )->value();
	return juju_blog_pro_is_about_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if about section content type is post.
 *
 * @since Juju Blog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function juju_blog_pro_is_about_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'juju_blog_pro_theme_options[about_content_type]' )->value();
	return juju_blog_pro_is_about_section_enable( $control ) && ( 'post' == $content_type );
}

/*====================contact=================*/

function juju_blog_pro_is_contact_section_enable( $control ) {
	return ( $control->manager->get_setting( 'juju_blog_pro_theme_options[contact_section_enable]' )->value() );
}

/*====================sortable=================*/

//pro layout 
function juju_blog_pro_is_default_layout( $control ) {
	$design = $control->manager->get_setting( 'juju_blog_pro_theme_options[home_layout]' )->value();
	return ( 'default-design' == $design );
}

//second layout 
function juju_blog_pro_is_second_layout( $control ) {
	$design = $control->manager->get_setting( 'juju_blog_pro_theme_options[home_layout]' )->value();
	return ( 'second-design' == $design );
}

//third layout 
function juju_blog_pro_is_third_layout( $control ) {
	$design = $control->manager->get_setting( 'juju_blog_pro_theme_options[home_layout]' )->value();
	return ( 'third-design' == $design );
}

//fourth layout 
function juju_blog_pro_is_fourth_layout( $control ) {
	$design = $control->manager->get_setting( 'juju_blog_pro_theme_options[home_layout]' )->value();
	return ( 'fourth-design' == $design );
}