<?php
/**
* Customizer default options
*
* @package Theme Palace
* @subpackage Juju Blog Pro
* @since Juju Blog Pro 1.0.0
* @return array An array of default values
*/

function juju_blog_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$juju_blog_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#2c2d39',
		'header_tagline_color'			=> '#990f12',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#990f12',
		'colorscheme'					=> 'default',
		'theme_version'					=> 'lite-version',
		'home_layout'					=> 'default-design',

		// loader
		'loader_enable'         		=> (bool) false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> (bool) true,
		'breadcrumb_separator'			=> '/',

		// layout 
		'site_layout'         			=> 'wide-layout',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> (bool) true,
		'menu_search'					=> (bool) true,
		'social_menu'					=> (bool) true,

		// pagination options
		'pagination_enable'         	=> (bool) true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s', '1: Year, 2: Site Title with home URL', 'juju-blog-pro' ), '[the-year]', '[site-link]' ),
		'scroll_top_visible'        	=> (bool) true,
		'footer_menu'        			=> (bool) true,
		'footer_enable'        			=> (bool) true,

		// reset options
		'reset_options'      			=> (bool) false,

		// homepage options
		'enable_frontpage_content' 		=> (bool) false,

		// homepage sections sortable
		'all_sortable'	=> 'slider,event_slider,upcomming_event,travel_search,top_destination,topics,stories,gallery,about,special_events,playlist,team,service,music_gallery,testimonial,counter,recent_posts,most_read,subscription,sponsor,blog_events,contact,instagram',

		'default_sortable'	=> 'slider,topics,stories,about,recent_posts,most_read,subscription,instagram',
		
		'second_sortable'	=> 'slider,travel_search,top_destination,stories,gallery,most_read,subscription',

		'third_sortable'	=> 'event_slider,about,special_events,team,service,upcomming_event,music_gallery,testimonial,subscription,blog_events,contact',

		'fourth_sortable'	=> 'event_slider,upcomming_event,about,playlist,team,music_gallery,counter,subscription,sponsor,blog_events',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'juju-blog-pro' ),
		'hide_image'					=> (bool) false,
		'hide_category'					=> (bool) false,
		'hide_author'					=> (bool) false,
		'hide_title'					=> (bool) false,
		'hide_description'				=> (bool) false,

		// single post theme options
		'single_post_hide_date' 		=> (bool) false,
		'single_post_hide_author'		=> (bool) false,
		'single_post_hide_category'		=> (bool) false,
		'single_post_hide_tags'			=> (bool) false,
		'single_post_hide_image'		=> (bool) false,
		'single_post_hide_description'	=> (bool) false,

		/* Front Page */

		// top_bar
		'top_bar_section_enable'	=> (bool) true,
		'top_bar_notice'			=> esc_html__( 'Lifestyle and Fashion Blog Theme For Everyone', 'juju-blog-pro' ),
		'top_bar_email'				=> esc_html__( 'info@themepalace.com', 'juju-blog-pro' ),

		// slider
		'slider_section_enable'			=> (bool) true,
		'slider_content_type'			=> 'post',
		'slider_autoplay'				=> (bool) false,
		'slider_count'					=> 3,

		// topics
		'topics_section_enable'			=> (bool) true,
		'topics_autoplay'			=> (bool) false,
		'topics_title'					=> esc_html__( 'Trending Topics', 'juju-blog-pro' ),
		'topics_content_type'			=> 'post',
		'topics_count'					=> 6,

		// stories
		'stories_section_enable'		=> (bool) true,
		'stories_title'					=> esc_html__( 'Top Stories', 'juju-blog-pro' ),

		//about 
		'about_section_enable'		=> (bool) true,
		'about_excerpt_length'		=> 30,
		'about_content_type'		=> 'post',
		'about_btn_text'			=> esc_html__( 'Read More', 'juju-blog-pro' ),

		//recent_posts 
		'recent_posts_section_enable'		=> (bool) true,
		'recent_posts_title'				=> esc_html__( 'Recent Posts', 'juju-blog-pro' ),
		'recent_posts_count'				=> 4,
		'recent_posts_excerpt_length'		=> 15,
		'recent_posts_content_type'			=> 'post',
		'recent_posts_btn_text'				=> esc_html__( 'Read More', 'juju-blog-pro' ),

		// most_read
		'most_read_section_enable'			=> (bool) true,
		'most_read_count'					=> 3,
		'most_read_content_type'			=> 'post',
		'most_read_title'					=> esc_html__( 'You May Have Missed', 'juju-blog-pro' ),

		// subscription
		'subscription_section_enable'	=> (bool) true,
		'subscription_title'			=> esc_html__( 'Newsletter Subscription', 'juju-blog-pro' ),
		'subscription_description'		=> esc_html__( 'Next thing you know, you have a new crew of people to hang out with fun, entertaining, and exciting.', 'juju-blog-pro' ),
		'subscription_btn_title'		=> esc_html__( 'Subscribe Now', 'juju-blog-pro' ),

		//instagram
		'instagram_section_enable'		=> (bool) true,
		'instagram_shortcode'			=> esc_html__( '[instagram-feed]', 'juju-blog-pro' ),

		//travel_search
		'travel_search_section_enable'		=> (bool) true,

		// top destination
		'top_destination_section_enable'		=> (bool) true,
		'top_destination_autoplay'				=> (bool) false,
		'top_destination_content_type'			=> 'category',
		'top_destination_count'					=> 4,
		'top_destination_title'					=> esc_html__( 'Choose your next adventure!', 'juju-blog-pro' ),
		'top_destination_btn_label'				=> esc_html__( 'Explore More', 'juju-blog-pro' ),

		// gallery
		'gallery_section_enable'		=> (bool) true,
		'gallery_autoplay'				=> (bool) false,
		'gallery_content_type'			=> 'category',
		'gallery_count'					=> 4,
		'gallery_title'					=> esc_html__( 'Make your own memories', 'juju-blog-pro' ),
		'gallery_btn_label'				=> esc_html__( 'View All', 'juju-blog-pro' ),

		// event_slider
		'event_slider_section_enable'		=> (bool) true,
		'event_slider_content_type'			=> 'post',
		'event_slider_autoplay'				=> (bool) false,
		'event_slider_count'				=> 3,
		'event_slider_excerpt_length'		=> 40,
		'event_slider_primary_btn'			=> esc_html__( 'Read More', 'juju-blog-pro' ),
		'event_slider_secondary_btn'		=> esc_html__( 'Buy Albums', 'juju-blog-pro' ),

		// playlist
		'playlist_section_enable'		=> (bool) true,
		'playlist_title'			=> esc_html__( 'Audio Tracks', 'juju-blog-pro' ),

		// Event
		'upcomming_event_section_enable'			=> true,
		'upcomming_event_content_type'			=> 'category',
		'upcomming_event_count'					=> 4,
		'upcomming_event_title'					=> esc_html__( 'Upcomming Events', 'juju-blog-pro' ),
		'upcomming_event_readmore'				=> esc_html__( 'Buy Ticket', 'juju-blog-pro' ),
		'upcomming_event_btn_title'				=> esc_html__( 'View All Events', 'juju-blog-pro' ),

		//team 
		'team_section_enable'					=> (bool) true,
		'team_content_type'						=> 'page',
		'team_count'							=> 3,
		'team_title'							=> esc_html__( 'Our Team', 'juju-blog-pro' ),

		//music_gallery 
		'music_gallery_section_enable'			=> (bool) true,
		'music_gallery_title'					=> esc_html__( 'Our Gallery', 'juju-blog-pro' ),
		'music_gallery_content_type'			=> 'category',
		'music_gallery_count'     			=> 9,

		// counter
		'counter_section_enable'		=> (bool) true,
		'counter_count'					=> 4,
		'counter_column'				=> 'col-4',

		// sponsor
		'sponsor_section_enable'		=> (bool) true,
		'sponsor_count'					=> 5,

		//blog_events 
		'blog_events_section_enable'		=> (bool) true,
		'blog_events_title'					=> esc_html__( 'Latest Events', 'juju-blog-pro' ),
		'blog_events_content_type'			=> 'post',
		'blog_events_count'					=> 3,
		'blog_events_excerpt_length'		=> 25,

		//special_events 
		'special_events_section_enable'		=> (bool) true,
		'special_events_title'				=> esc_html__( 'Special Events', 'juju-blog-pro' ),
		'special_events_content_type'		=> 'post',
		'special_events_count'				=> 4,
		'special_events_excerpt_length'		=> 15,

		//service 
		'service_section_enable'		=> (bool) true,
		'service_content_type'			=> 'post',
		'service_title'					=> esc_html__( 'Our Services', 'juju-blog-pro' ),
		'service_count'					=> 3,
		'service_excerpt_length'		=> 20,

		// testimonial
		'testimonial_section_enable'					=> (bool) true,
		'testimonial_section_autoplay_slider_enable'	=> (bool) true,
		'testimonial_content_type'						=> 'page',
		'testimonial_count'								=> 3,
		'testimonial_excerpt_length'					=> 45,

		// contact
		'contact_section_enable'			=> (bool) true,
		'contact_section_title'				=> esc_html__( 'Contact Us', 'juju-blog-pro' ),
		'contact_number'					=> esc_html__( '045-236-8759', 'juju-blog-pro' ),
		'contact_email'						=> esc_html__( 'info@jujublog.com', 'juju-blog-pro' ),
		'contact_address'					=> esc_html__( 'UN Park, America', 'juju-blog-pro' ),
		

		);

$output = apply_filters( 'juju_blog_pro_default_theme_options', $juju_blog_pro_default_options );

// Sort array in ascending order, according to the key:
if ( ! empty( $output ) ) {
	ksort( $output );
}

return $output;
}