<?php
/**
 * About Section options
 *
 * @package Theme Palace
 * @subpackage Juju Blog Pro
 * @since Juju Blog Pro 1.0.0
 */

// Add About section
$wp_customize->add_section( 'juju_blog_pro_about_section', array(
	'title'             => esc_html__( 'About Us','juju-blog-pro' ),
	'description'       => esc_html__( 'About Us Section options.', 'juju-blog-pro' ),
	'panel'             => 'juju_blog_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return (
            juju_blog_pro_is_default_layout( $control )
            ||
            juju_blog_pro_is_third_layout( $control )
            ||
            juju_blog_pro_is_fourth_layout( $control )
        );
    },
) );

// About content enable control and setting
$wp_customize->add_setting( 'juju_blog_pro_theme_options[about_section_enable]', array(
	'default'			=> 	$options['about_section_enable'],
	'sanitize_callback' => 'juju_blog_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Juju_Blog_Pro_Switch_Control( $wp_customize, 'juju_blog_pro_theme_options[about_section_enable]', array(
	'label'             => esc_html__( 'About Section Enable', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_about_section',
	'on_off_label' 		=> juju_blog_pro_switch_options(),
) ) );

// about title setting and control
$wp_customize->add_setting( 'juju_blog_pro_theme_options[about_btn_text]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_btn_text'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'juju_blog_pro_theme_options[about_btn_text]', array(
	'label'           	=> esc_html__( 'Button Label', 'juju-blog-pro' ),
	'section'        	=> 'juju_blog_pro_about_section',
	'active_callback' 	=> 'juju_blog_pro_is_about_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'juju_blog_pro_theme_options[about_btn_text]', array(
		'selector'            => '#juju_blog_pro_about_section .view-more a',
		'settings'            => 'juju_blog_pro_theme_options[about_btn_text]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'juju_blog_pro_about_btn_text_partial',
    ) );
}

// long Excerpt length setting and control.
$wp_customize->add_setting( 'juju_blog_pro_theme_options[about_excerpt_length]', array(
	'sanitize_callback' => 'juju_blog_pro_sanitize_number_range',
	'validate_callback' => 'juju_blog_pro_validate_long_excerpt',
	'default'			=> $options['about_excerpt_length'],
	) );

$wp_customize->add_control( 'juju_blog_pro_theme_options[about_excerpt_length]', array(
	'label'       		=> esc_html__( 'About Excerpt Length', 'juju-blog-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in about posts.', 'juju-blog-pro' ),
	'section'     		=> 'juju_blog_pro_about_section',
	'active_callback' 	=> 'juju_blog_pro_is_about_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
		),
	) );

// About content type control and setting
$wp_customize->add_setting( 'juju_blog_pro_theme_options[about_content_type]', array(
	'default'          	=> $options['about_content_type'],
	'sanitize_callback' => 'juju_blog_pro_sanitize_select',
) );

$wp_customize->add_control( 'juju_blog_pro_theme_options[about_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_about_section',
	'type'				=> 'select',
	'active_callback' 	=> 'juju_blog_pro_is_about_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'juju-blog-pro' ),
		'post' 		=> esc_html__( 'Post', 'juju-blog-pro' ),
	),
) );

// about pages drop down chooser control and setting
$wp_customize->add_setting( 'juju_blog_pro_theme_options[about_content_page]', array(
	'sanitize_callback' => 'juju_blog_pro_sanitize_page',
) );

$wp_customize->add_control( new Juju_Blog_Pro_Dropdown_Chooser( $wp_customize, 'juju_blog_pro_theme_options[about_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_about_section',
	'choices'			=> juju_blog_pro_page_choices(),
	'active_callback'	=> 'juju_blog_pro_is_about_section_content_page_enable',
) ) );

// about posts drop down chooser control and setting
$wp_customize->add_setting( 'juju_blog_pro_theme_options[about_content_post]', array(
	'sanitize_callback' => 'juju_blog_pro_sanitize_page',
) );

$wp_customize->add_control( new Juju_Blog_Pro_Dropdown_Chooser( $wp_customize, 'juju_blog_pro_theme_options[about_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_about_section',
	'choices'			=> juju_blog_pro_post_choices(),
	'active_callback'	=> 'juju_blog_pro_is_about_section_content_post_enable',
) ) );