<?php
/**
 * Contact Section options
 *
 * @package Theme Palace
 * @subpackage  Juju Blog Pro
 * @since  Juju Blog Pro 1.0.0
 */

// Add Contact section
$wp_customize->add_section( 'juju_blog_pro_contact_section', 
    array(
        'title'             => esc_html__( 'Contact us','juju-blog-pro' ),
        'description'       => esc_html__( 'Contact us  Section options.', 'juju-blog-pro' ),
        'panel'             => 'juju_blog_pro_front_page_panel',
        'active_callback'   => function( $control ) {
            return ( 
                juju_blog_pro_is_third_layout( $control )
            );
        },
    ) 
);

// Contact content enable control and setting
$wp_customize->add_setting( 'juju_blog_pro_theme_options[contact_section_enable]', 
    array(
        'default'			=> 	$options['contact_section_enable'],
        'sanitize_callback' => 'juju_blog_pro_sanitize_switch_control',
    ) 
);

$wp_customize->add_control( new Juju_Blog_Pro_Switch_Control( $wp_customize, 'juju_blog_pro_theme_options[contact_section_enable]',
    array(
        'label'             => esc_html__( 'Contact Section Enable', 'juju-blog-pro' ),
        'section'           => 'juju_blog_pro_contact_section',
        'on_off_label' 		=> juju_blog_pro_switch_options(),
    ) 
) );

// contact section title control and setting
$wp_customize->add_setting( 'juju_blog_pro_theme_options[contact_section_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'			=> 	$options['contact_section_title'],
        'transport'			=>'postMessage'
    ) 
);

$wp_customize->add_control('juju_blog_pro_theme_options[contact_section_title]',
    array(
        'label'             => esc_html__( 'Section Title', 'juju-blog-pro' ),
        'section'           => 'juju_blog_pro_contact_section',
        'type'              => 'text',
        'active_callback'	=> 'juju_blog_pro_is_contact_section_enable',
    )
);
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'juju_blog_pro_theme_options[contact_section_title]', array(
        'selector'            => '#juju_blog_pro_contact_section .section-title',
        'settings'            => 'juju_blog_pro_theme_options[contact_section_title]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'juju_blog_pro_contact_section_title_partial',
    ) );
}

 // contact section title control and setting
    $wp_customize->add_setting( 'juju_blog_pro_theme_options[contact_map_shortcode]',
        array(
            'sanitize_callback' => 'sanitize_text_field',
            'transport'         =>'refresh'
        ) 
    );
    
    $wp_customize->add_control('juju_blog_pro_theme_options[contact_map_shortcode]',
        array(
            'label'             => esc_html__( 'Map Shortcode', 'juju-blog-pro' ),
            'section'           => 'juju_blog_pro_contact_section',
            'type'              => 'text',
            'active_callback'   => 'juju_blog_pro_is_contact_section_enable',
        )
    );

// contact section title control and setting
$wp_customize->add_setting( 'juju_blog_pro_theme_options[contact_section_shortcode]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=>'refresh'
    ) 
);

$wp_customize->add_control('juju_blog_pro_theme_options[contact_section_shortcode]',
    array(
        'label'             => esc_html__( 'Contact Shortcode', 'juju-blog-pro' ),
        'section'           => 'juju_blog_pro_contact_section',
        'type'              => 'text',
        'active_callback'	=> 'juju_blog_pro_is_contact_section_enable',
    )
);

//contact_number
$wp_customize->add_setting('juju_blog_pro_theme_options[contact_number]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['contact_number'],
    )
);

$wp_customize->add_control('juju_blog_pro_theme_options[contact_number]',
    array(
        'section'			=> 'juju_blog_pro_contact_section',
        'label'				=> esc_html__( 'Contact Number:', 'juju-blog-pro' ),
        'type'          	=>'text',
        'active_callback' 	=> 'juju_blog_pro_is_contact_section_enable'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'juju_blog_pro_theme_options[contact_number]',
		array(
			'selector'            => '#juju_blog_pro_contact_section span.phone',
			'settings'            => 'juju_blog_pro_theme_options[contact_number]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'juju_blog_pro_contact_number_partial',
		) 
	);
}

//contact_email
$wp_customize->add_setting('juju_blog_pro_theme_options[contact_email]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'         => 'postMessage',
        'default'           => $options['contact_email'],
    )
);

$wp_customize->add_control('juju_blog_pro_theme_options[contact_email]',
    array(
        'section'           => 'juju_blog_pro_contact_section',
        'label'             => esc_html__( 'E-mail:', 'juju-blog-pro' ),
        'type'              =>'text',
        'active_callback'   => 'juju_blog_pro_is_contact_section_enable'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'juju_blog_pro_theme_options[contact_email]',
        array(
            'selector'            => '#juju_blog_pro_contact_section span.message',
            'settings'            => 'juju_blog_pro_theme_options[contact_email]',
            'fallback_refresh'    => true,
            'container_inclusive' => false,
            'render_callback'     => 'juju_blog_pro_contact_email_partial',
        ) 
    );
}

//contact_address
$wp_customize->add_setting('juju_blog_pro_theme_options[contact_address]',
array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['contact_address'],
    )
);

$wp_customize->add_control('juju_blog_pro_theme_options[contact_address]',
    array(
        'section'			=> 'juju_blog_pro_contact_section',
        'label'				=> esc_html__( 'Address:', 'juju-blog-pro' ),
        'type'          	=>'text',
        'active_callback' 	=> 'juju_blog_pro_is_contact_section_enable'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'juju_blog_pro_theme_options[contact_address]',
		array(
            'selector'            => '#juju_blog_pro_contact_section span.address',
			'settings'            => 'juju_blog_pro_theme_options[contact_address]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'juju_blog_pro_contact_address_partial',
            ) 
        );
    }