<?php
/**
* Event Slider Section options
*
* @package Theme Palace
* @subpackage Juju Blog Pro
* @since Juju Blog Pro 1.0.0
*/

// Add Event Slider section
$wp_customize->add_section( 'juju_blog_pro_event_slider_section', array(
	'title'             => esc_html__( 'Event Slider','juju-blog-pro' ),
	'description'       => esc_html__( 'Event Slider Section options.', 'juju-blog-pro' ),
	'panel'             => 'juju_blog_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return (
            juju_blog_pro_is_third_layout( $control )
            ||
            juju_blog_pro_is_fourth_layout( $control )
        );
    },
	) );

// Event Slider content enable control and setting
$wp_customize->add_setting( 'juju_blog_pro_theme_options[event_slider_section_enable]', array(
	'default'			=> 	$options['event_slider_section_enable'],
	'sanitize_callback' => 'juju_blog_pro_sanitize_switch_control',
	) );

$wp_customize->add_control( new Juju_Blog_Pro_Switch_Control( $wp_customize, 'juju_blog_pro_theme_options[event_slider_section_enable]', array(
	'label'             => esc_html__( 'Event Slider Section Enable', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_event_slider_section',
	'on_off_label' 		=> juju_blog_pro_switch_options(),
	) ) );

// Event Slider content enable control and setting
$wp_customize->add_setting( 'juju_blog_pro_theme_options[event_slider_autoplay]', array(
	'default'			=> 	$options['event_slider_autoplay'],
	'sanitize_callback' => 'juju_blog_pro_sanitize_switch_control',
	) );

$wp_customize->add_control( new Juju_Blog_Pro_Switch_Control( $wp_customize, 'juju_blog_pro_theme_options[event_slider_autoplay]', array(
	'label'             => esc_html__( 'Auto Play Enable', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_event_slider_section',
	'on_off_label' 		=> juju_blog_pro_switch_options(),
	'active_callback' 	=> 'juju_blog_pro_is_event_slider_section_enable',
	) ) );

// Event social icons number control and setting
$wp_customize->add_setting( 'juju_blog_pro_theme_options[event_slider_count]', array(
	'default'          	=> $options['event_slider_count'],
	'sanitize_callback' => 'juju_blog_pro_sanitize_number_range',
	'validate_callback' => 'juju_blog_pro_validate_event_slider_count',
	) );

$wp_customize->add_control( 'juju_blog_pro_theme_options[event_slider_count]', array(
	'label'             => esc_html__( 'Number of Slides', 'juju-blog-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 50. Please input the valid number and save. Then refresh the page to see the change.', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_event_slider_section',
	'active_callback'   => 'juju_blog_pro_is_event_slider_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 50,
		'style' => 'width: 100px;'
		),
	) );

// long Excerpt length setting and control.
$wp_customize->add_setting( 'juju_blog_pro_theme_options[event_slider_excerpt_length]', array(
	'sanitize_callback' => 'juju_blog_pro_sanitize_number_range',
	'validate_callback' => 'juju_blog_pro_validate_long_excerpt',
	'default'			=> $options['event_slider_excerpt_length'],
	) );

$wp_customize->add_control( 'juju_blog_pro_theme_options[event_slider_excerpt_length]', array(
	'label'       		=> esc_html__( 'Blog Excerpt Length', 'juju-blog-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in blog posts.', 'juju-blog-pro' ),
	'section'     		=> 'juju_blog_pro_blog_section',
	'active_callback' 	=> 'juju_blog_pro_is_blog_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
		),
	) );

// Event Slider content type control and setting
$wp_customize->add_setting( 'juju_blog_pro_theme_options[event_slider_content_type]', array(
	'default'          	=> $options['event_slider_content_type'],
	'sanitize_callback' => 'juju_blog_pro_sanitize_select',
	) );

$wp_customize->add_control( 'juju_blog_pro_theme_options[event_slider_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_event_slider_section',
	'type'				=> 'select',
	'active_callback' 	=> 'juju_blog_pro_is_event_slider_section_enable',
	'choices'			=> juju_blog_pro_event_slider_content_type(),
	) );

for ( $i = 1; $i <= $options['event_slider_count']; $i++ ) :

// event_slider pages drop down chooser control and setting
$wp_customize->add_setting( 'juju_blog_pro_theme_options[event_slider_content_page_' . $i . ']', array(
	'sanitize_callback' => 'juju_blog_pro_sanitize_page',
	) );

$wp_customize->add_control( new Juju_Blog_Pro_Dropdown_Chooser( $wp_customize, 'juju_blog_pro_theme_options[event_slider_content_page_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Page %d', 'juju-blog-pro' ), $i ),
	'section'           => 'juju_blog_pro_event_slider_section',
	'choices'			=> juju_blog_pro_page_choices(),
	'active_callback'	=> 'juju_blog_pro_is_event_slider_section_content_page_enable',
	) ) );

// event_slider posts drop down chooser control and setting
$wp_customize->add_setting( 'juju_blog_pro_theme_options[event_slider_content_post_' . $i . ']', array(
	'sanitize_callback' => 'juju_blog_pro_sanitize_page',
	) );

$wp_customize->add_control( new Juju_Blog_Pro_Dropdown_Chooser( $wp_customize, 'juju_blog_pro_theme_options[event_slider_content_post_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Post %d', 'juju-blog-pro' ), $i ),
	'section'           => 'juju_blog_pro_event_slider_section',
	'choices'			=> juju_blog_pro_post_choices(),
	'active_callback'	=> 'juju_blog_pro_is_event_slider_section_content_post_enable',
	) ) );

// event posts drop down chooser control and setting
	$wp_customize->add_setting( 'juju_blog_pro_theme_options[event_slider_content_event_' . $i . ']', array(
		'sanitize_callback' => 'juju_blog_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Juju_Blog_Pro_Dropdown_Chooser( $wp_customize, 'juju_blog_pro_theme_options[event_slider_content_event_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Event %d', 'juju-blog-pro' ), $i ),
		'section'           => 'juju_blog_pro_event_slider_section',
		'choices'			=> juju_blog_pro_event_choices(),
		'active_callback'	=> 'juju_blog_pro_is_event_slider_section_content_event_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'juju_blog_pro_theme_options[event_slider_content_category]', array(
	'sanitize_callback' => 'juju_blog_pro_sanitize_single_category',
	) ) ;

$wp_customize->add_control( new Juju_Blog_Pro_Dropdown_Taxonomies_Control( $wp_customize,'juju_blog_pro_theme_options[event_slider_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'juju-blog-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_event_slider_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'juju_blog_pro_is_event_slider_section_content_category_enable'
	) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'juju_blog_pro_theme_options[event_slider_content_event_category]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Juju_Blog_Pro_Dropdown_Taxonomies_Control( $wp_customize,'juju_blog_pro_theme_options[event_slider_content_event_category]', array(
	'label'             => esc_html__( 'Select Event Category', 'juju-blog-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_event_slider_section',
	'taxonomy'			=> 'tp-event-category',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'juju_blog_pro_is_event_slider_section_content_event_category_enable'
) ) );

// event_slider btn title setting and control
$wp_customize->add_setting( 'juju_blog_pro_theme_options[event_slider_primary_btn]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['event_slider_primary_btn'],
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'juju_blog_pro_theme_options[event_slider_primary_btn]', array(
    'label'             => esc_html__( 'Primary Button Label', 'juju-blog-pro' ),
    'section'           => 'juju_blog_pro_event_slider_section',
    'active_callback'   => 'juju_blog_pro_is_event_slider_section_enable',
    'type'              => 'text',
) );

// event_slider btn title setting and control
$wp_customize->add_setting( 'juju_blog_pro_theme_options[event_slider_secondary_btn]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['event_slider_secondary_btn'],
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'juju_blog_pro_theme_options[event_slider_secondary_btn]', array(
    'label'             => esc_html__( 'Secondary Button Label', 'juju-blog-pro' ),
    'section'           => 'juju_blog_pro_event_slider_section',
    'active_callback'   => 'juju_blog_pro_is_event_slider_section_enable',
    'type'              => 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'juju_blog_pro_theme_options[event_slider_secondary_btn]', array(
        'selector'            => '#business-event_slider-section div.read-more a',
        'settings'            => 'juju_blog_pro_theme_options[event_slider_secondary_btn]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'juju_blog_pro_event_slider_secondary_btn_partial',
    ) );
}

// event_slider btn link setting and control
$wp_customize->add_setting( 'juju_blog_pro_theme_options[event_slider_btn_link]', array(
    'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'juju_blog_pro_theme_options[event_slider_btn_link]', array(
    'label'             => esc_html__( 'Button Link', 'juju-blog-pro' ),
    'section'           => 'juju_blog_pro_event_slider_section',
    'active_callback'   => 'juju_blog_pro_is_event_slider_section_enable',
    'type'              => 'url',
) );