<?php
/**
 * Playlist Section options
 *
 * @package Theme Palace
 * @subpackage Juju Blog Pro
 * @since Juju Blog Pro 1.0.0
 */

// Add Playlist section
$wp_customize->add_section( 'juju_blog_pro_playlist_section', array(
	'title'             => esc_html__( 'Playlist','juju-blog-pro' ),
	'description'       => esc_html__( 'Playlist Section options.', 'juju-blog-pro' ),
	'panel'             => 'juju_blog_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return (
            juju_blog_pro_is_fourth_layout( $control )
        );
    },
) );

// Playlist content enable control and setting
$wp_customize->add_setting( 'juju_blog_pro_theme_options[playlist_section_enable]', array(
	'default'			=> 	$options['playlist_section_enable'],
	'sanitize_callback' => 'juju_blog_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Juju_Blog_Pro_Switch_Control( $wp_customize, 'juju_blog_pro_theme_options[playlist_section_enable]', array(
	'label'             => esc_html__( 'Playlist Section Enable', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_playlist_section',
	'on_off_label' 		=> juju_blog_pro_switch_options(),
) ) );

// playlist title setting and control
$wp_customize->add_setting( 'juju_blog_pro_theme_options[playlist_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['playlist_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'juju_blog_pro_theme_options[playlist_title]', array(
	'label'           	=> esc_html__( 'Title', 'juju-blog-pro' ),
	'section'        	=> 'juju_blog_pro_playlist_section',
	'active_callback' 	=> 'juju_blog_pro_is_playlist_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'juju_blog_pro_theme_options[playlist_title]', array(
		'selector'            => '#juju_blog_pro_playlist_section .section-title',
		'settings'            => 'juju_blog_pro_theme_options[playlist_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'juju_blog_pro_playlist_title_partial',
    ) );
}

// playlist image setting and control.
$wp_customize->add_setting( 'juju_blog_pro_theme_options[playlist_bg_image]', array(
	'sanitize_callback' => 'juju_blog_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'juju_blog_pro_theme_options[playlist_bg_image]',
		array(
		'label'       		=> esc_html__( 'Background Image', 'juju-blog-pro' ),
		'section'     		=> 'juju_blog_pro_playlist_section',
		'active_callback'	=> 'juju_blog_pro_is_playlist_section_enable',
) ) );
	
	// playlist posts drop down chooser control and setting
	$wp_customize->add_setting( 'juju_blog_pro_theme_options[playlist_content]', array(
		'sanitize_callback' => 'juju_blog_pro_sanitize_array_int',
	) );

	$wp_customize->add_control( new Juju_Blog_Pro_Multiple_Dropdown_Chooser( $wp_customize, 'juju_blog_pro_theme_options[playlist_content]', array(
		'label'             => esc_html__( 'Select Multiple Audios', 'juju-blog-pro' ),
		'section'           => 'juju_blog_pro_playlist_section',
		'choices'			=> juju_blog_pro_audio_choices(),
		'active_callback'	=> 'juju_blog_pro_is_playlist_section_enable',
	) ) );