<?php
/**
 * Recent Posts Section options
 *
 * @package Theme Palace
 * @subpackage Juju Blog Pro
 * @since Juju Blog Pro 1.0.0
 */

// Add Recent Posts section
$wp_customize->add_section( 'juju_blog_pro_most_recent_posts_section', array(
	'title'             => esc_html__( 'Recent Posts','juju-blog-pro' ),
	'description'       => esc_html__( 'Recent Posts Section options.', 'juju-blog-pro' ),
	'panel'				=> 'juju_blog_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return (
            juju_blog_pro_is_default_layout( $control )
        );
    },

) );

// Recent Posts content enable control and setting
$wp_customize->add_setting( 'juju_blog_pro_theme_options[recent_posts_section_enable]', array(
	'default'			=> 	$options['recent_posts_section_enable'],
	'sanitize_callback' => 'juju_blog_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Juju_Blog_Pro_Switch_Control( $wp_customize, 'juju_blog_pro_theme_options[recent_posts_section_enable]', array(
	'label'             => esc_html__( 'Recent Posts Section Enable', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_most_recent_posts_section',
	'on_off_label' 		=> juju_blog_pro_switch_options(),
) ) );

// Recent Posts btn label setting and control
$wp_customize->add_setting( 'juju_blog_pro_theme_options[recent_posts_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['recent_posts_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'juju_blog_pro_theme_options[recent_posts_title]', array(
	'label'           	=> esc_html__( 'Section Title', 'juju-blog-pro' ),
	'section'        	=> 'juju_blog_pro_most_recent_posts_section',
	'active_callback' 	=> 'juju_blog_pro_is_recent_posts_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'juju_blog_pro_theme_options[recent_posts_title]', array(
		'selector'            => '#juju_blog_pro_most_recent_posts_section .section-title',
		'settings'            => 'juju_blog_pro_theme_options[recent_posts_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'juju_blog_pro_recent_posts_title_partial',
    ) );
}

// content type control and setting
$wp_customize->add_setting( 'juju_blog_pro_theme_options[recent_posts_count]', array(
	'default'          	=> $options['recent_posts_count'],
	'sanitize_callback' => 'juju_blog_pro_sanitize_number_range',
	'validate_callback' => 'juju_blog_pro_validate_recent_posts_count',
) );

$wp_customize->add_control( 'juju_blog_pro_theme_options[recent_posts_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'juju-blog-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 50. Please input the valid number and save. Then refresh the page to see the change.', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_most_recent_posts_section',
	'active_callback'   => 'juju_blog_pro_is_recent_posts_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 50,
		'style' => 'width: 100px;'
		),
) );

// long Excerpt length setting and control.
$wp_customize->add_setting( 'juju_blog_pro_theme_options[recent_posts_excerpt_length]', array(
	'sanitize_callback' => 'juju_blog_pro_sanitize_number_range',
	'validate_callback' => 'juju_blog_pro_validate_long_excerpt',
	'default'			=> $options['recent_posts_excerpt_length'],
	) );

$wp_customize->add_control( 'juju_blog_pro_theme_options[recent_posts_excerpt_length]', array(
	'label'       		=> esc_html__( 'Recent Posts Excerpt Length', 'juju-blog-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in recent_posts posts.', 'juju-blog-pro' ),
	'section'     		=> 'juju_blog_pro_most_recent_posts_section',
	'active_callback' 	=> 'juju_blog_pro_is_recent_posts_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
		),
	) );

// Recent Posts content type control and setting
$wp_customize->add_setting( 'juju_blog_pro_theme_options[recent_posts_content_type]', array(
	'default'          	=> $options['recent_posts_content_type'],
	'sanitize_callback' => 'juju_blog_pro_sanitize_select',
) );

$wp_customize->add_control( 'juju_blog_pro_theme_options[recent_posts_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_most_recent_posts_section',
	'type'				=> 'select',
	'active_callback' 	=> 'juju_blog_pro_is_recent_posts_section_enable',
	'choices'			=> array(
		'page'      => esc_html__( 'Page', 'juju-blog-pro' ),
		'post'      => esc_html__( 'Post', 'juju-blog-pro' ),
		'category'  => esc_html__( 'Category', 'juju-blog-pro' ),
		),
) );

for ( $i = 1; $i <= $options['recent_posts_count']; $i++ ) :
	// recent_posts pages drop down chooser control and setting
	$wp_customize->add_setting( 'juju_blog_pro_theme_options[recent_posts_content_page_' . $i . ']', array(
		'sanitize_callback' => 'juju_blog_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Juju_Blog_Pro_Dropdown_Chooser( $wp_customize, 'juju_blog_pro_theme_options[recent_posts_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'juju-blog-pro' ), $i ),
		'section'           => 'juju_blog_pro_most_recent_posts_section',
		'choices'			=> juju_blog_pro_page_choices(),
		'active_callback'	=> 'juju_blog_pro_is_recent_posts_section_content_page_enable',
	) ) );

	// recent_posts posts drop down chooser control and setting
	$wp_customize->add_setting( 'juju_blog_pro_theme_options[recent_posts_content_post_' . $i . ']', array(
		'sanitize_callback' => 'juju_blog_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Juju_Blog_Pro_Dropdown_Chooser( $wp_customize, 'juju_blog_pro_theme_options[recent_posts_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'juju-blog-pro' ), $i ),
		'section'           => 'juju_blog_pro_most_recent_posts_section',
		'choices'			=> juju_blog_pro_post_choices(),
		'active_callback'	=> 'juju_blog_pro_is_recent_posts_section_content_post_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'juju_blog_pro_theme_options[recent_posts_content_category]', array(
	'sanitize_callback' => 'juju_blog_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Juju_Blog_Pro_Dropdown_Taxonomies_Control( $wp_customize,'juju_blog_pro_theme_options[recent_posts_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'juju-blog-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_most_recent_posts_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'juju_blog_pro_is_recent_posts_section_content_category_enable'
) ) );