<?php
/**
* service Section options
*
* @package Theme Palace
* @subpackage Juju Blog Pro
* @since Juju Blog Pro 1.0.0
*/

// Add service section
$wp_customize->add_section( 'juju_blog_pro_our_service_section', array(
	'title'             => esc_html__( 'Service','juju-blog-pro' ),
	'description'       => esc_html__( 'Service Section options.', 'juju-blog-pro' ),
	'panel'             => 'juju_blog_pro_front_page_panel',
	'active_callback'   => function( $control ) {
		return (
			juju_blog_pro_is_third_layout( $control )
			);
	},
	) );

// service content enable control and setting
$wp_customize->add_setting( 'juju_blog_pro_theme_options[service_section_enable]', array(
	'default'			=> 	$options['service_section_enable'],
	'sanitize_callback' => 'juju_blog_pro_sanitize_switch_control',
	) );

$wp_customize->add_control( new Juju_Blog_Pro_Switch_Control( $wp_customize, 'juju_blog_pro_theme_options[service_section_enable]', array(
	'label'             => esc_html__( 'Service Section Enable', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_our_service_section',
	'on_off_label' 		=> juju_blog_pro_switch_options(),
	) ) );

// service title setting and control
$wp_customize->add_setting( 'juju_blog_pro_theme_options[service_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['service_title'],
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'juju_blog_pro_theme_options[service_title]', array(
	'label'           	=> esc_html__( 'Title', 'juju-blog-pro' ),
	'section'        	=> 'juju_blog_pro_our_service_section',
	'active_callback' 	=> 'juju_blog_pro_is_service_section_enable',
	'type'				=> 'text',
	) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'juju_blog_pro_theme_options[service_title]', array(
		'selector'            => '#juju_blog_pro_our_service_section .section-title',
		'settings'            => 'juju_blog_pro_theme_options[service_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'juju_blog_pro_service_title_partial',
		) );
}

// long Excerpt length setting and control.
$wp_customize->add_setting( 'juju_blog_pro_theme_options[service_excerpt_length]', array(
	'sanitize_callback' => 'juju_blog_pro_sanitize_number_range',
	'validate_callback' => 'juju_blog_pro_validate_long_excerpt',
	'default'			=> $options['service_excerpt_length'],
	) );

$wp_customize->add_control( 'juju_blog_pro_theme_options[service_excerpt_length]', array(
	'label'       		=> esc_html__( 'Service Excerpt Length', 'juju-blog-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in service posts.', 'juju-blog-pro' ),
	'section'     		=> 'juju_blog_pro_our_service_section',
	'active_callback' 	=> 'juju_blog_pro_is_service_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
		),
	) );

// Event social icons number control and setting
$wp_customize->add_setting( 'juju_blog_pro_theme_options[service_count]', array(
	'default'          	=> $options['service_count'],
	'sanitize_callback' => 'juju_blog_pro_sanitize_number_range',
	'validate_callback' => 'juju_blog_pro_validate_service_count',
	) );

$wp_customize->add_control( 'juju_blog_pro_theme_options[service_count]', array(
	'label'             => esc_html__( 'Number of Slides', 'juju-blog-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 50. Please input the valid number and save. Then refresh the page to see the change.', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_our_service_section',
	'active_callback'   => 'juju_blog_pro_is_service_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 50,
		'style' => 'width: 100px;'
		),
	) );

// service content type control and setting
$wp_customize->add_setting( 'juju_blog_pro_theme_options[service_content_type]', array(
	'default'          	=> $options['service_content_type'],
	'sanitize_callback' => 'juju_blog_pro_sanitize_select',
	) );

$wp_customize->add_control( 'juju_blog_pro_theme_options[service_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_our_service_section',
	'type'				=> 'select',
	'active_callback' 	=> 'juju_blog_pro_is_service_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'juju-blog-pro' ),
		'post' 		=> esc_html__( 'Post', 'juju-blog-pro' ),
		'category' 	=> esc_html__( 'Category', 'juju-blog-pro' ),
		),
	) );

for ( $i = 1; $i <= $options['service_count']; $i++ ) :

// service note control and setting
	$wp_customize->add_setting( 'juju_blog_pro_theme_options[service_content_icon_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
		) );

$wp_customize->add_control( new Juju_Blog_Pro_Icon_Picker( $wp_customize, 'juju_blog_pro_theme_options[service_content_icon_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Icon %d', 'juju-blog-pro' ), $i ),
	'section'           => 'juju_blog_pro_our_service_section',
	'active_callback'	=> 'juju_blog_pro_is_service_section_enable',
	) ) );

// service pages drop down chooser control and setting
$wp_customize->add_setting( 'juju_blog_pro_theme_options[service_content_page_' . $i . ']', array(
	'sanitize_callback' => 'juju_blog_pro_sanitize_page',
	) );

$wp_customize->add_control( new Juju_Blog_Pro_Dropdown_Chooser( $wp_customize, 'juju_blog_pro_theme_options[service_content_page_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Page %d', 'juju-blog-pro' ), $i ),
	'section'           => 'juju_blog_pro_our_service_section',
	'choices'			=> juju_blog_pro_page_choices(),
	'active_callback'	=> 'juju_blog_pro_is_service_section_content_page_enable',
	) ) );

// service posts drop down chooser control and setting
$wp_customize->add_setting( 'juju_blog_pro_theme_options[service_content_post_' . $i . ']', array(
	'sanitize_callback' => 'juju_blog_pro_sanitize_page',
	) );

$wp_customize->add_control( new Juju_Blog_Pro_Dropdown_Chooser( $wp_customize, 'juju_blog_pro_theme_options[service_content_post_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Post %d', 'juju-blog-pro' ), $i ),
	'section'           => 'juju_blog_pro_our_service_section',
	'choices'			=> juju_blog_pro_post_choices(),
	'active_callback'	=> 'juju_blog_pro_is_service_section_content_post_enable',
	) ) );

$wp_customize->add_setting( 'juju_blog_pro_theme_options[service_hr_'. $i .']', array(
	'sanitize_callback' => 'sanitize_text_field'
	) );

$wp_customize->add_control( new Juju_Blog_Pro_Customize_Horizontal_Line( $wp_customize, 'juju_blog_pro_theme_options[service_hr_'. $i .']',
	array(
		'section'           => 'juju_blog_pro_our_service_section',
		'active_callback'   => 'juju_blog_pro_is_service_section_enable',
		'type'            => 'hr'
		) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'juju_blog_pro_theme_options[service_content_category]', array(
	'sanitize_callback' => 'juju_blog_pro_sanitize_single_category',
	) ) ;

$wp_customize->add_control( new Juju_Blog_Pro_Dropdown_Taxonomies_Control( $wp_customize,'juju_blog_pro_theme_options[service_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'juju-blog-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_our_service_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'juju_blog_pro_is_service_section_content_category_enable'
	) ) );