<?php
/**
* Slider Section options
*
* @package Theme Palace
* @subpackage Juju Blog Pro
* @since Juju Blog Pro 1.0.0
*/

// Add Slider section
$wp_customize->add_section( 'juju_blog_pro_featured_slider_section', array(
	'title'             => esc_html__( 'Main Slider','juju-blog-pro' ),
	'description'       => esc_html__( 'Slider Section options.', 'juju-blog-pro' ),
	'panel'             => 'juju_blog_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return (
            juju_blog_pro_is_default_layout( $control )
            ||
            juju_blog_pro_is_second_layout( $control )
        );
    },
	) );

// Slider content enable control and setting
$wp_customize->add_setting( 'juju_blog_pro_theme_options[slider_section_enable]', array(
	'default'			=> 	$options['slider_section_enable'],
	'sanitize_callback' => 'juju_blog_pro_sanitize_switch_control',
	) );

$wp_customize->add_control( new Juju_Blog_Pro_Switch_Control( $wp_customize, 'juju_blog_pro_theme_options[slider_section_enable]', array(
	'label'             => esc_html__( 'Slider Section Enable', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_featured_slider_section',
	'on_off_label' 		=> juju_blog_pro_switch_options(),
	) ) );

// Slider content enable control and setting
$wp_customize->add_setting( 'juju_blog_pro_theme_options[slider_autoplay]', array(
	'default'			=> 	$options['slider_autoplay'],
	'sanitize_callback' => 'juju_blog_pro_sanitize_switch_control',
	) );

$wp_customize->add_control( new Juju_Blog_Pro_Switch_Control( $wp_customize, 'juju_blog_pro_theme_options[slider_autoplay]', array(
	'label'             => esc_html__( 'Auto Play Enable', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_featured_slider_section',
	'on_off_label' 		=> juju_blog_pro_switch_options(),
	'active_callback' 	=> 'juju_blog_pro_is_slider_section_enable',
	) ) );

// Event social icons number control and setting
$wp_customize->add_setting( 'juju_blog_pro_theme_options[slider_count]', array(
	'default'          	=> $options['slider_count'],
	'sanitize_callback' => 'juju_blog_pro_sanitize_number_range',
	'validate_callback' => 'juju_blog_pro_validate_slider_count',
	) );

$wp_customize->add_control( 'juju_blog_pro_theme_options[slider_count]', array(
	'label'             => esc_html__( 'Number of Slides', 'juju-blog-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 50. Please input the valid number and save. Then refresh the page to see the change.', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_featured_slider_section',
	'active_callback'   => 'juju_blog_pro_is_slider_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 50,
		'style' => 'width: 100px;'
		),
	) );

// Slider content type control and setting
$wp_customize->add_setting( 'juju_blog_pro_theme_options[slider_content_type]', array(
	'default'          	=> $options['slider_content_type'],
	'sanitize_callback' => 'juju_blog_pro_sanitize_select',
	) );

$wp_customize->add_control( 'juju_blog_pro_theme_options[slider_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_featured_slider_section',
	'type'				=> 'select',
	'active_callback' 	=> 'juju_blog_pro_is_slider_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'juju-blog-pro' ),
		'post' 		=> esc_html__( 'Post', 'juju-blog-pro' ),
		'category' 	=> esc_html__( 'Category', 'juju-blog-pro' ),
		),
	) );

for ( $i = 1; $i <= $options['slider_count']; $i++ ) :

// slider pages drop down chooser control and setting
$wp_customize->add_setting( 'juju_blog_pro_theme_options[slider_content_page_' . $i . ']', array(
	'sanitize_callback' => 'juju_blog_pro_sanitize_page',
	) );

$wp_customize->add_control( new Juju_Blog_Pro_Dropdown_Chooser( $wp_customize, 'juju_blog_pro_theme_options[slider_content_page_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Page %d', 'juju-blog-pro' ), $i ),
	'section'           => 'juju_blog_pro_featured_slider_section',
	'choices'			=> juju_blog_pro_page_choices(),
	'active_callback'	=> 'juju_blog_pro_is_slider_section_content_page_enable',
	) ) );

// slider posts drop down chooser control and setting
$wp_customize->add_setting( 'juju_blog_pro_theme_options[slider_content_post_' . $i . ']', array(
	'sanitize_callback' => 'juju_blog_pro_sanitize_page',
	) );

$wp_customize->add_control( new Juju_Blog_Pro_Dropdown_Chooser( $wp_customize, 'juju_blog_pro_theme_options[slider_content_post_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Post %d', 'juju-blog-pro' ), $i ),
	'section'           => 'juju_blog_pro_featured_slider_section',
	'choices'			=> juju_blog_pro_post_choices(),
	'active_callback'	=> 'juju_blog_pro_is_slider_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'juju_blog_pro_theme_options[slider_content_category]', array(
	'sanitize_callback' => 'juju_blog_pro_sanitize_single_category',
	) ) ;

$wp_customize->add_control( new Juju_Blog_Pro_Dropdown_Taxonomies_Control( $wp_customize,'juju_blog_pro_theme_options[slider_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'juju-blog-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_featured_slider_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'juju_blog_pro_is_slider_section_content_category_enable'
	) ) );