<?php
/**
 * Sponsor Section options
 *
 * @package Theme Palace
 * @sub_package Juju Blog Pro
 * @since Juju Blog Pro 1.0.0
 */

// Add Sponsor section
$wp_customize->add_section( 'juju_blog_pro_sponsor_section', array(
	'title'             => esc_html__( 'Sponsor','juju-blog-pro' ),
	'description'       => esc_html__( 'Sponsor Section options.', 'juju-blog-pro' ),
	'panel'             => 'juju_blog_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return ( 
        	juju_blog_pro_is_fourth_layout( $control )  
        );
    },
) );

// Sponsor content enable control and setting
$wp_customize->add_setting( 'juju_blog_pro_theme_options[sponsor_section_enable]', array(
	'default'			=> 	$options['sponsor_section_enable'],
	'sanitize_callback' => 'juju_blog_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Juju_Blog_Pro_Switch_Control( $wp_customize, 'juju_blog_pro_theme_options[sponsor_section_enable]', array(
	'label'             => esc_html__( 'Sponsor Section Enable', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_sponsor_section',
	'on_off_label' 		=> juju_blog_pro_switch_options(),
) ) );

// Event social icons number control and setting
$wp_customize->add_setting( 'juju_blog_pro_theme_options[sponsor_count]', array(
	'default'          	=> $options['sponsor_count'],
	'sanitize_callback' => 'juju_blog_pro_sanitize_number_range',
	'validate_callback' => 'juju_blog_pro_validate_sponsor_count',
) );

$wp_customize->add_control( 'juju_blog_pro_theme_options[sponsor_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'juju-blog-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 50. Please input the valid number and save. Then refresh the page to see the change.', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_sponsor_section',
	'active_callback'   => 'juju_blog_pro_is_sponsor_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 50,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['sponsor_count']; $i++ ) :

	// Sponsor image setting and control.
	$wp_customize->add_setting( 'juju_blog_pro_theme_options[sponsor_image_' . $i . ']', array(
		'sanitize_callback' => 'juju_blog_pro_sanitize_image',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'juju_blog_pro_theme_options[sponsor_image_' . $i . ']',
			array(
			'label'       		=> sprintf( esc_html__( 'Image %d', 'juju-blog-pro' ), $i),
			'section'     		=> 'juju_blog_pro_sponsor_section',
			'active_callback'	=> 'juju_blog_pro_is_sponsor_section_enable',
	) ) );

	// Sponsor url setting and control
	$wp_customize->add_setting( 'juju_blog_pro_theme_options[sponsor_url_' . $i . ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'juju_blog_pro_theme_options[sponsor_url_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Sponsor Url %d', 'juju-blog-pro' ), $i),
		'section'        	=> 'juju_blog_pro_sponsor_section',
		'active_callback' 	=> 'juju_blog_pro_is_sponsor_section_enable',
		'type'				=> 'url',
	) );

endfor;