<?php
/**
 * Subscription Section options
 *
 * @package Theme Palace
 * @subpackage Juju Blog Pro
 * @since Juju Blog Pro 1.0.0
 */

// Add Subscription section
$wp_customize->add_section( 'juju_blog_pro_subscribe_now_section', array(
	'title'             => esc_html__( 'Subscription','juju-blog-pro' ),
	'description'       => esc_html__( 'Note: To activate this section you need to install Jetpack Plugin and activate subscription module.', 'juju-blog-pro' ),
	'panel'             => 'juju_blog_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return (
            juju_blog_pro_is_default_layout( $control )
            ||
            juju_blog_pro_is_second_layout( $control )
            ||
            juju_blog_pro_is_third_layout( $control )
            ||
            juju_blog_pro_is_fourth_layout( $control )
        );
    },
) );

// Subscription content enable control and setting
$wp_customize->add_setting( 'juju_blog_pro_theme_options[subscription_section_enable]', array(
	'default'			=> 	$options['subscription_section_enable'],
	'sanitize_callback' => 'juju_blog_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Juju_Blog_Pro_Switch_Control( $wp_customize, 'juju_blog_pro_theme_options[subscription_section_enable]', array(
	'label'             => esc_html__( 'Subscription Section Enable', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_subscribe_now_section',
	'on_off_label' 		=> juju_blog_pro_switch_options(),
) ) );

// subscription title setting and control
$wp_customize->add_setting( 'juju_blog_pro_theme_options[subscription_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['subscription_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'juju_blog_pro_theme_options[subscription_title]', array(
	'label'           	=> esc_html__( 'Title', 'juju-blog-pro' ),
	'section'        	=> 'juju_blog_pro_subscribe_now_section',
	'active_callback' 	=> 'juju_blog_pro_is_subscription_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'juju_blog_pro_theme_options[subscription_title]', array(
		'selector'            => '#juju_blog_pro_subscribe_now_section h2.section-title',
		'settings'            => 'juju_blog_pro_theme_options[subscription_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'juju_blog_pro_subscription_title_partial',
    ) );
}

// subscription description setting and control
$wp_customize->add_setting( 'juju_blog_pro_theme_options[subscription_description]', array(
	'sanitize_callback' => 'wp_kses_post',	
	'default'			=> $options['subscription_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'juju_blog_pro_theme_options[subscription_description]', array(
	'label'           	=> esc_html__( 'Description', 'juju-blog-pro' ),
	'section'        	=> 'juju_blog_pro_subscribe_now_section',
	'active_callback' 	=> 'juju_blog_pro_is_subscription_section_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'juju_blog_pro_theme_options[subscription_description]', array(
		'selector'            => '#juju_blog_pro_subscribe_now_section .subscribe-text p',
		'settings'            => 'juju_blog_pro_theme_options[subscription_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'juju_blog_pro_subscription_description_partial',
    ) );
}

// subscription btn title setting and control
$wp_customize->add_setting( 'juju_blog_pro_theme_options[subscription_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['subscription_btn_title'],
) );

$wp_customize->add_control( 'juju_blog_pro_theme_options[subscription_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'juju-blog-pro' ),
	'section'        	=> 'juju_blog_pro_subscribe_now_section',
	'active_callback' 	=> 'juju_blog_pro_is_subscription_section_enable',
	'type'				=> 'text',
) );