<?php
/**
 * Team Section options
 *
 * @package Theme Palace
 * @subpackage Juju Blog Pro
 * @since Juju Blog Pro 1.0.0
 */

// Add team section
$wp_customize->add_section( 'juju_blog_pro_team_section', array(
	'title'             => esc_html__( 'Team','juju-blog-pro' ),
	'description'       => esc_html__( 'Team Section options.', 'juju-blog-pro' ),
	'panel'             => 'juju_blog_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return (
            juju_blog_pro_is_third_layout( $control )
            ||
            juju_blog_pro_is_fourth_layout( $control )
        );
    },
) );

// team content enable control and setting
$wp_customize->add_setting( 'juju_blog_pro_theme_options[team_section_enable]', array(
	'default'			=> 	$options['team_section_enable'],
	'sanitize_callback' => 'juju_blog_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Juju_Blog_Pro_Switch_Control( $wp_customize, 'juju_blog_pro_theme_options[team_section_enable]', array(
	'label'             => esc_html__( 'Team Section Enable', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_team_section',
	'on_off_label' 		=> juju_blog_pro_switch_options(),
) ) );

// team title setting and control
$wp_customize->add_setting( 'juju_blog_pro_theme_options[team_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['team_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'juju_blog_pro_theme_options[team_title]', array(
	'label'           	=> esc_html__( 'Title', 'juju-blog-pro' ),
	'section'        	=> 'juju_blog_pro_team_section',
	'active_callback' 	=> 'juju_blog_pro_is_team_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'juju_blog_pro_theme_options[team_title]', array(
		'selector'            => '#juju_blog_pro_team_section h2.section-title',
		'settings'            => 'juju_blog_pro_theme_options[team_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'juju_blog_pro_team_title_partial',
    ) );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'juju_blog_pro_theme_options[team_count]', array(
	'default'          	=> $options['team_count'],
	'sanitize_callback' => 'juju_blog_pro_sanitize_number_range',
	'validate_callback' => 'juju_blog_pro_validate_team_count',
) );

$wp_customize->add_control( 'juju_blog_pro_theme_options[team_count]', array(
	'label'             => esc_html__( 'Number of team', 'juju-blog-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 50. Please input the valid number and save. Then refresh the page to see the change.', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_team_section',
	'active_callback'   => 'juju_blog_pro_is_team_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 50,
		'style' => 'width: 100px;'
		),
) );

// team content type control and setting
$wp_customize->add_setting( 'juju_blog_pro_theme_options[team_content_type]', array(
	'default'          	=> $options['team_content_type'],
	'sanitize_callback' => 'juju_blog_pro_sanitize_select',
) );

$wp_customize->add_control( 'juju_blog_pro_theme_options[team_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_team_section',
	'type'				=> 'select',
	'active_callback' 	=> 'juju_blog_pro_is_team_section_enable',
	'choices'			=> array(
            'page'      => esc_html__( 'Page', 'juju-blog-pro' ),
            'post'      => esc_html__( 'Post', 'juju-blog-pro' ),
            'category'  => esc_html__( 'Category', 'juju-blog-pro' ),
        ),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'juju_blog_pro_theme_options[team_content_category]', array(
	'sanitize_callback' => 'juju_blog_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Juju_Blog_Pro_Dropdown_Taxonomies_Control( $wp_customize,'juju_blog_pro_theme_options[team_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'juju-blog-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_team_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'juju_blog_pro_is_team_section_content_category_enable'
) ) );

for ( $i = 1; $i <= $options['team_count']; $i++ ) :

	// team pages drop down chooser control and setting
	$wp_customize->add_setting( 'juju_blog_pro_theme_options[team_content_page_' . $i . ']', array(
		'sanitize_callback' => 'juju_blog_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Juju_Blog_Pro_Dropdown_Chooser( $wp_customize, 'juju_blog_pro_theme_options[team_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'juju-blog-pro' ), $i ),
		'section'           => 'juju_blog_pro_team_section',
		'choices'			=> juju_blog_pro_page_choices(),
		'active_callback'	=> 'juju_blog_pro_is_team_section_content_page_enable',
	) ) );

	// team posts drop down chooser control and setting
	$wp_customize->add_setting( 'juju_blog_pro_theme_options[team_content_post_' . $i . ']', array(
		'sanitize_callback' => 'juju_blog_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Juju_Blog_Pro_Dropdown_Chooser( $wp_customize, 'juju_blog_pro_theme_options[team_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'juju-blog-pro' ), $i ),
		'section'           => 'juju_blog_pro_team_section',
		'choices'			=> juju_blog_pro_post_choices(),
		'active_callback'	=> 'juju_blog_pro_is_team_section_content_post_enable',
	) ) );

	// team custom content
	$wp_customize->add_setting( 'juju_blog_pro_theme_options[team_position_' . $i . ']', array(
		'sanitize_callback' => 'wp_kses_post',
	) );

	$wp_customize->add_control( 'juju_blog_pro_theme_options[team_position_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Position %d', 'juju-blog-pro' ), $i ),
		'section'           => 'juju_blog_pro_team_section',
		'active_callback'	=> 'juju_blog_pro_is_team_section_enable',
	) );

	// team social
	$wp_customize->add_setting( 'juju_blog_pro_theme_options[team_social_' . $i. ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new Juju_Blog_Pro_Multi_Input_Custom_Control( $wp_customize, 'juju_blog_pro_theme_options[team_social_' . $i. ']', array(
		'label'             => esc_html__( 'Social ', 'juju-blog-pro' ),
		'button_text'       => esc_html__( 'Add social.', 'juju-blog-pro' ),
		'section'           => 'juju_blog_pro_team_section',
		'active_callback' 	=> 'juju_blog_pro_is_team_section_enable',
	) ) );

	// team hr setting and control
	$wp_customize->add_setting( 'juju_blog_pro_theme_options[team_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Juju_Blog_Pro_Customize_Horizontal_Line( $wp_customize, 'juju_blog_pro_theme_options[team_hr_'. $i .']',
		array(
			'section'         => 'juju_blog_pro_team_section',
			'active_callback' => 'juju_blog_pro_is_team_section_enable',
			'type'			  => 'hr'
	) ) );

endfor;