<?php
/**
 * Popular Destination Section options
 *
 * @package Theme Palace
 * @subpackage Juju Blog Pro
 * @since Juju Blog Pro 1.0.0
 */

// Add Popular Destination section
$wp_customize->add_section( 'juju_blog_pro_top_destination_section', array(
	'title'             => esc_html__( 'Popular Destination','juju-blog-pro' ),
	'description'       => esc_html__( 'Popular Destination Section options.', 'juju-blog-pro' ),
	'panel'             => 'juju_blog_pro_front_page_panel',
	'active_callback'   => function( $control ) {
		return (
			juju_blog_pro_is_second_layout( $control )
			);
	},
) );

// Popular Destination content enable control and setting
$wp_customize->add_setting( 'juju_blog_pro_theme_options[top_destination_section_enable]', array(
	'default'			=> 	$options['top_destination_section_enable'],
	'sanitize_callback' => 'juju_blog_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Juju_Blog_Pro_Switch_Control( $wp_customize, 'juju_blog_pro_theme_options[top_destination_section_enable]', array(
	'label'             => esc_html__( 'Popular Destination Section Enable', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_top_destination_section',
	'on_off_label' 		=> juju_blog_pro_switch_options(),
) ) );

// Popular Destination content enable control and setting
$wp_customize->add_setting( 'juju_blog_pro_theme_options[top_destination_autoplay]', array(
	'default'			=> 	$options['top_destination_autoplay'],
	'sanitize_callback' => 'juju_blog_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Juju_Blog_Pro_Switch_Control( $wp_customize, 'juju_blog_pro_theme_options[top_destination_autoplay]', array(
	'label'             => esc_html__( 'Autoplay Enable', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_top_destination_section',
	'on_off_label' 		=> juju_blog_pro_switch_options(),
) ) );

// top destination title setting and control
$wp_customize->add_setting( 'juju_blog_pro_theme_options[top_destination_title]', array(
	'default'			=> $options['top_destination_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'juju_blog_pro_theme_options[top_destination_title]', array(
	'label'           	=> esc_html__( 'Title', 'juju-blog-pro' ),
	'section'        	=> 'juju_blog_pro_top_destination_section',
	'active_callback' 	=> 'juju_blog_pro_is_top_destination_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'juju_blog_pro_theme_options[top_destination_title]', array(
		'selector'            => '#juju_blog_pro_top_destination_section .section-title',
		'settings'            => 'juju_blog_pro_theme_options[top_destination_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'juju_blog_pro_top_destination_title_partial',
    ) );
}

//Popular Destination post count number control and setting
$wp_customize->add_setting( 'juju_blog_pro_theme_options[top_destination_count]', array(
	'default'          	=> $options['top_destination_count'],
	'sanitize_callback' => 'juju_blog_pro_sanitize_number_range',
	'validate_callback' => 'juju_blog_pro_validate_top_destination_count',
) );

$wp_customize->add_control( 'juju_blog_pro_theme_options[top_destination_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'juju-blog-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 50. Please input the valid number and save. Then refresh the page to see the change.', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_top_destination_section',
	'active_callback'   => 'juju_blog_pro_is_top_destination_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 50,
		'style' => 'width: 100px;'
		),
) );

// Popular Destination content type control and setting
$wp_customize->add_setting( 'juju_blog_pro_theme_options[top_destination_content_type]', array(
	'default'          	=> $options['top_destination_content_type'],
	'sanitize_callback' => 'juju_blog_pro_sanitize_select',
) );

$wp_customize->add_control( 'juju_blog_pro_theme_options[top_destination_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_top_destination_section',
	'type'				=> 'select',
	'active_callback' 	=> 'juju_blog_pro_is_top_destination_section_enable',
	'choices'			=> juju_blog_pro_top_destination_content_type(),
) );

for ( $i=1; $i <= $options['top_destination_count']; $i++ ) { 
	// Popular deatination pages drop down chooser control and setting
	$wp_customize->add_setting( 'juju_blog_pro_theme_options[top_destination_content_page_' . $i . ']', array(
		'sanitize_callback' => 'juju_blog_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Juju_Blog_Pro_Dropdown_Chooser( $wp_customize, 'juju_blog_pro_theme_options[top_destination_content_page_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Page %d', 'juju-blog-pro' ), $i ),
		'section'           => 'juju_blog_pro_top_destination_section',
		'choices'			=> juju_blog_pro_page_choices(),
		'active_callback'	=> 'juju_blog_pro_is_top_destination_section_content_page_enable',
	) ) );

	// Popular deatination posts drop down chooser control and setting
	$wp_customize->add_setting( 'juju_blog_pro_theme_options[top_destination_content_post_' . $i . ']', array(
		'sanitize_callback' => 'juju_blog_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Juju_Blog_Pro_Dropdown_Chooser( $wp_customize, 'juju_blog_pro_theme_options[top_destination_content_post_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select posts %d', 'juju-blog-pro' ), $i ),
		'section'           => 'juju_blog_pro_top_destination_section',
		'choices'			=> juju_blog_pro_post_choices(),
		'active_callback'	=> 'juju_blog_pro_is_top_destination_section_content_post_enable',
	) ) );

	// top_destination trips drop down chooser control and setting
	$wp_customize->add_setting( 'juju_blog_pro_theme_options[top_destination_content_trip_' . $i . ']', array(
		'sanitize_callback' => 'juju_blog_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Juju_Blog_Pro_Dropdown_Chooser( $wp_customize, 'juju_blog_pro_theme_options[top_destination_content_trip_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Trip %d', 'juju-blog-pro' ), $i ),
		'section'           => 'juju_blog_pro_top_destination_section',
		'choices'			=> juju_blog_pro_trip_choices(),
		'active_callback'	=> 'juju_blog_pro_is_top_destination_section_content_trip_enable',
	) ) );
}

// Add dropdown category setting and control.
$wp_customize->add_setting(  'juju_blog_pro_theme_options[top_destination_content_category]', array(
	'sanitize_callback' => 'juju_blog_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Juju_Blog_Pro_Dropdown_Taxonomies_Control( $wp_customize,'juju_blog_pro_theme_options[top_destination_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'juju-blog-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_top_destination_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'juju_blog_pro_is_top_destination_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'juju_blog_pro_theme_options[top_destination_content_trip_types]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Juju_Blog_Pro_Dropdown_Taxonomies_Control( $wp_customize,'juju_blog_pro_theme_options[top_destination_content_trip_types]', array(
	'label'             => esc_html__( 'Select Trip Types', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_top_destination_section',
	'taxonomy'			=> 'itinerary_types',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'juju_blog_pro_is_top_destination_section_content_trip_types_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'juju_blog_pro_theme_options[top_destination_content_activity]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Juju_Blog_Pro_Dropdown_Taxonomies_Control( $wp_customize,'juju_blog_pro_theme_options[top_destination_content_activity]', array(
	'label'             => esc_html__( 'Select Activities', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_top_destination_section',
	'taxonomy'			=> 'activity',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'juju_blog_pro_is_top_destination_section_content_activity_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'juju_blog_pro_theme_options[top_destination_content_destination]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Juju_Blog_Pro_Dropdown_Taxonomies_Control( $wp_customize,'juju_blog_pro_theme_options[top_destination_content_destination]', array(
	'label'             => esc_html__( 'Select Destinations', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_top_destination_section',
	'taxonomy'			=> 'travel_locations',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'juju_blog_pro_is_top_destination_section_content_destination_enable'
) ) );


// Popular deatination btn label setting and control
$wp_customize->add_setting( 'juju_blog_pro_theme_options[top_destination_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['top_destination_btn_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'juju_blog_pro_theme_options[top_destination_btn_label]', array(
	'label'           	=> esc_html__( 'Button Label', 'juju-blog-pro' ),
	'section'        	=> 'juju_blog_pro_top_destination_section',
	'active_callback' 	=> 'juju_blog_pro_is_top_destination_section_enable',
	'type'				=> 'text',
) );