<?php
/**
 * Event Section options
 *
 * @package Theme Palace
 * @subpackage Juju Blog Pro
 * @since Juju Blog Pro 1.0.0
 */

// Add Event section
$wp_customize->add_section( 'juju_blog_pro_music_event_section', array(
	'title'             => esc_html__( 'Upcomming Event','juju-blog-pro' ),
	'description'       => esc_html__( 'Upcomming Event Section options.', 'juju-blog-pro' ),
	'panel'             => 'juju_blog_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return (
            juju_blog_pro_is_third_layout( $control )
            ||
            juju_blog_pro_is_fourth_layout( $control )
        );
    },
) );

// Upcomming Event content enable control and setting
$wp_customize->add_setting( 'juju_blog_pro_theme_options[upcomming_event_section_enable]', array(
	'default'			=> 	$options['upcomming_event_section_enable'],
	'sanitize_callback' => 'juju_blog_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Juju_Blog_Pro_Switch_Control( $wp_customize, 'juju_blog_pro_theme_options[upcomming_event_section_enable]', array(
	'label'             => esc_html__( 'Upcomming Event Section Enable', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_music_event_section',
	'on_off_label' 		=> juju_blog_pro_switch_options(),
) ) );

// event title setting and control
$wp_customize->add_setting( 'juju_blog_pro_theme_options[upcomming_event_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['upcomming_event_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'juju_blog_pro_theme_options[upcomming_event_title]', array(
	'label'           	=> esc_html__( 'Title', 'juju-blog-pro' ),
	'section'        	=> 'juju_blog_pro_music_event_section',
	'active_callback' 	=> 'juju_blog_pro_is_upcomming_event_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'juju_blog_pro_theme_options[upcomming_event_title]', array(
		'selector'            => '#juju_blog_pro_music_event_section h2.section-title',
		'settings'            => 'juju_blog_pro_theme_options[upcomming_event_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'juju_blog_pro_upcomming_event_title_partial',
    ) );
}

// event readmore setting and control
$wp_customize->add_setting( 'juju_blog_pro_theme_options[upcomming_event_readmore]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['upcomming_event_readmore'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'juju_blog_pro_theme_options[upcomming_event_readmore]', array(
	'label'           	=> esc_html__( 'Primary Button Label', 'juju-blog-pro' ),
	'section'        	=> 'juju_blog_pro_music_event_section',
	'active_callback' 	=> 'juju_blog_pro_is_upcomming_event_section_enable',
	'type'				=> 'text',
) );

// Event content type control and setting
$wp_customize->add_setting( 'juju_blog_pro_theme_options[upcomming_event_content_type]', array(
	'default'          	=> $options['upcomming_event_content_type'],
	'sanitize_callback' => 'juju_blog_pro_sanitize_select',
) );

$wp_customize->add_control( 'juju_blog_pro_theme_options[upcomming_event_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_music_event_section',
	'type'				=> 'select',
	'active_callback' 	=> 'juju_blog_pro_is_upcomming_event_section_enable',
	'choices'			=> juju_blog_pro_upcomming_event_content_type(),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'juju_blog_pro_theme_options[upcomming_event_count]', array(
	'default'          	=> $options['upcomming_event_count'],
	'sanitize_callback' => 'juju_blog_pro_sanitize_number_range',
	'validate_callback' => 'juju_blog_pro_validate_upcomming_event_count',
) );

$wp_customize->add_control( 'juju_blog_pro_theme_options[upcomming_event_count]', array(
	'label'             => esc_html__( 'Number of Event', 'juju-blog-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 50. Please input the valid number and save. Then refresh the page to see the change.', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_music_event_section',
	'active_callback'   => 'juju_blog_pro_is_upcomming_event_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 50,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['upcomming_event_count']; $i++ ) :

	// event posts drop down chooser control and setting
	$wp_customize->add_setting( 'juju_blog_pro_theme_options[upcomming_event_content_page_' . $i . ']', array(
		'sanitize_callback' => 'juju_blog_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Juju_Blog_Pro_Dropdown_Chooser( $wp_customize, 'juju_blog_pro_theme_options[upcomming_event_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'juju-blog-pro' ), $i ),
		'section'           => 'juju_blog_pro_music_event_section',
		'choices'			=> juju_blog_pro_page_choices(),
		'active_callback'	=> 'juju_blog_pro_is_upcomming_event_section_content_page_enable',
	) ) );

	// event posts drop down chooser control and setting
	$wp_customize->add_setting( 'juju_blog_pro_theme_options[upcomming_event_content_post_' . $i . ']', array(
		'sanitize_callback' => 'juju_blog_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Juju_Blog_Pro_Dropdown_Chooser( $wp_customize, 'juju_blog_pro_theme_options[upcomming_event_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'juju-blog-pro' ), $i ),
		'section'           => 'juju_blog_pro_music_event_section',
		'choices'			=> juju_blog_pro_post_choices(),
		'active_callback'	=> 'juju_blog_pro_is_upcomming_event_section_content_post_enable',
	) ) );

	// event posts drop down chooser control and setting
	$wp_customize->add_setting( 'juju_blog_pro_theme_options[upcomming_event_content_upcomming_event_' . $i . ']', array(
		'sanitize_callback' => 'juju_blog_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Juju_Blog_Pro_Dropdown_Chooser( $wp_customize, 'juju_blog_pro_theme_options[upcomming_event_content_upcomming_event_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Event %d', 'juju-blog-pro' ), $i ),
		'section'           => 'juju_blog_pro_music_event_section',
		'choices'			=> juju_blog_pro_event_choices(),
		'active_callback'	=> 'juju_blog_pro_is_upcomming_event_section_content_upcomming_event_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'juju_blog_pro_theme_options[upcomming_event_content_category]', array(
	'sanitize_callback' => 'juju_blog_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Juju_Blog_Pro_Dropdown_Taxonomies_Control( $wp_customize,'juju_blog_pro_theme_options[upcomming_event_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'juju-blog-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_music_event_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'juju_blog_pro_is_upcomming_event_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'juju_blog_pro_theme_options[upcomming_event_content_upcomming_event_category]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Juju_Blog_Pro_Dropdown_Taxonomies_Control( $wp_customize,'juju_blog_pro_theme_options[upcomming_event_content_upcomming_event_category]', array(
	'label'             => esc_html__( 'Select Event Category', 'juju-blog-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'juju-blog-pro' ),
	'section'           => 'juju_blog_pro_music_event_section',
	'taxonomy'			=> 'tp-event-category',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'juju_blog_pro_is_upcomming_event_section_content_upcomming_event_category_enable'
) ) );

// event btn title setting and control
$wp_customize->add_setting( 'juju_blog_pro_theme_options[upcomming_event_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['upcomming_event_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'juju_blog_pro_theme_options[upcomming_event_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'juju-blog-pro' ),
	'section'        	=> 'juju_blog_pro_music_event_section',
	'active_callback' 	=> 'juju_blog_pro_is_upcomming_event_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'juju_blog_pro_theme_options[upcomming_event_btn_title]', array(
		'selector'            => '#juju_blog_pro_music_event_section .read-more a.btn',
		'settings'            => 'juju_blog_pro_theme_options[upcomming_event_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'juju_blog_pro_upcomming_event_btn_title_partial',
    ) );
}

// event btn link setting and control
$wp_customize->add_setting( 'juju_blog_pro_theme_options[upcomming_event_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'juju_blog_pro_theme_options[upcomming_event_btn_link]', array(
	'label'           	=> esc_html__( 'Button Url', 'juju-blog-pro' ),
	'section'        	=> 'juju_blog_pro_music_event_section',
	'active_callback' 	=> 'juju_blog_pro_is_upcomming_event_section_enable',
	'type'				=> 'url',
) );