<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage Juju Blog Pro
 * @since Juju Blog Pro 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function juju_blog_pro_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'juju-blog-pro' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function juju_blog_pro_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'juju-blog-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of products for post choices.
 * @return Array Array of post ids and name.
 */
function juju_blog_pro_product_choices() {
    $posts = get_posts( array( 'numberposts' => -1, 'post_type' => 'product' ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'juju-blog-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of trips for post choices.
 * @return Array Array of post ids and name.
 */
function juju_blog_pro_trip_choices() {
    $posts = get_posts( array( 'post_type' => 'itineraries', 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'juju-blog-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of events for post choices.
 * @return Array Array of post ids and name.
 */
function juju_blog_pro_event_choices() {
$posts = get_posts( array( 'numberposts' => -1, 'post_type' => 'tp-event' ) );
$choices = array();
$choices[0] = esc_html__( '--Select--', 'juju-blog-pro' );
foreach ( $posts as $post ) {
$choices[ $post->ID ] = $post->post_title;
}
return  $choices;
}

/**
 * List of category for category choices.
 * @return Array Array of post ids and name.
 */
function juju_blog_pro_category_choices() {
    $tax_args = array(
        'hierarchical' => 0,
        'taxonomy'     => 'category',
    );
    $taxonomies = get_categories( $tax_args );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'juju-blog-pro' );
    foreach ( $taxonomies as $tax ) {
        $choices[ $tax->term_id ] = $tax->name;
    }
    return  $choices;
}


if ( ! function_exists( 'juju_blog_pro_typography_options' ) ) :
    function juju_blog_pro_typography_options(){
    $font_family_arr = array();
    $font_family_arr[''] = esc_html__( '--Default--', 'juju-blog-pro' );

    // Make the request
    $request = wp_remote_get( get_theme_file_uri( 'assets/webfonts.json' ) );

    if( is_wp_error( $request ) ) {
        return false; // Bail early
    }
     // Retrieve the data
    $body = wp_remote_retrieve_body( $request );
    $data = json_decode( $body );
    if ( ! empty( $data ) ) {
        foreach ( $data->items as $items => $fonts ) {
            $family_str_arr = explode( ' ', $fonts->family );
            $family_value = implode( '+', $family_str_arr );
            $font_family_arr[ $family_value ] = $fonts->family;
        }
    }

    return $font_family_arr;
}
endif;

if ( ! function_exists( 'juju_blog_pro_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function juju_blog_pro_selected_sidebar() {
        $juju_blog_pro_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'juju-blog-pro' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'juju-blog-pro' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'juju-blog-pro' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'juju-blog-pro' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'juju-blog-pro' ),
        );

        $output = apply_filters( 'juju_blog_pro_selected_sidebar', $juju_blog_pro_selected_sidebar );

        return $output;
    }
endif;

if ( ! function_exists( 'juju_blog_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function juju_blog_pro_site_layout() {
        $juju_blog_pro_site_layout = array(
            'wide-layout'  => get_template_directory_uri() . '/assets/images/full.png',
            'boxed-layout' => get_template_directory_uri() . '/assets/images/boxed.png',
            'frame-layout' => get_template_directory_uri() . '/assets/images/framed.png',
        );

        $output = apply_filters( 'juju_blog_pro_site_layout', $juju_blog_pro_site_layout );
        return $output;
    }
endif;


if ( ! function_exists( 'juju_blog_pro_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function juju_blog_pro_global_sidebar_position() {
        $juju_blog_pro_global_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'juju_blog_pro_global_sidebar_position', $juju_blog_pro_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'juju_blog_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function juju_blog_pro_sidebar_position() {
        $juju_blog_pro_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
            'no-sidebar-content'   => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'juju_blog_pro_sidebar_position', $juju_blog_pro_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'juju_blog_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function juju_blog_pro_pagination_options() {
        $juju_blog_pro_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'juju-blog-pro' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'juju-blog-pro' ),
            'infinite'  => esc_html__( 'Infinite', 'juju-blog-pro' ),
        );

        $output = apply_filters( 'juju_blog_pro_pagination_options', $juju_blog_pro_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'juju_blog_pro_get_spinner_list' ) ) :
    /**
     * List of spinner icons options.
     * @return array List of all spinner icon options.
     */
    function juju_blog_pro_get_spinner_list() {
        $arr = array(
            'default'               => esc_html__( 'Default', 'juju-blog-pro' ),
            'spinner-wheel'         => esc_html__( 'Wheel', 'juju-blog-pro' ),
            'spinner-double-circle' => esc_html__( 'Double Circle', 'juju-blog-pro' ),
            'spinner-two-way'       => esc_html__( 'Two Way', 'juju-blog-pro' ),
            'spinner-umbrella'      => esc_html__( 'Umbrella', 'juju-blog-pro' ),
            'spinner-dots'          => esc_html__( 'Dots', 'juju-blog-pro' ),
            'spinner-one-way'       => esc_html__( 'One Way', 'juju-blog-pro' ),
            'spinner-fidget'        => esc_html__( 'Fidget', 'juju-blog-pro' ),
        );
        return apply_filters( 'juju_blog_pro_spinner_list', $arr );
    }
endif;

if ( ! function_exists( 'juju_blog_pro_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function juju_blog_pro_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'juju-blog-pro' ),
            'off'       => esc_html__( 'Disable', 'juju-blog-pro' )
        );
        return apply_filters( 'juju_blog_pro_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'juju_blog_pro_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function juju_blog_pro_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'juju-blog-pro' ),
            'off'       => esc_html__( 'No', 'juju-blog-pro' )
        );
        return apply_filters( 'juju_blog_pro_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'juju_blog_pro_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function juju_blog_pro_sortable_sections() {
        $sections = array();
        $sections = array(
            'slider'                => esc_html__( 'Slider Section', 'juju-blog-pro' ),
            'topics'                => esc_html__( 'Trending Topics Section', 'juju-blog-pro' ),
            'stories'               => esc_html__( 'Top Stories Section', 'juju-blog-pro' ),
            'about'                 => esc_html__( 'About Section', 'juju-blog-pro' ),
            'recent_posts'          => esc_html__( 'Recent Posts Section', 'juju-blog-pro' ),
            'most_read'             => esc_html__( 'Most Read Section', 'juju-blog-pro' ),
            'subscription'          => esc_html__( 'Subscription Section', 'juju-blog-pro' ),
            'instagram'             => esc_html__( 'Instagram Section', 'juju-blog-pro' ),
            'travel_search'         => esc_html__( 'Travel Search Section', 'juju-blog-pro' ),
            'top_destination'       => esc_html__( 'Top Destination Section', 'juju-blog-pro' ),
            'gallery'               => esc_html__( 'Gallery Section', 'juju-blog-pro' ),
            'event_slider'          => esc_html__( 'Event Slider Section', 'juju-blog-pro' ),
            'upcomming_event'       => esc_html__( 'Upcomming Event Section', 'juju-blog-pro' ),
            'playlist'              => esc_html__( 'Playlist Section', 'juju-blog-pro' ),
            'team'                  => esc_html__( 'Team Section', 'juju-blog-pro' ),
            'music_gallery'         => esc_html__( 'Music Gallery Section', 'juju-blog-pro' ),
            'counter'               => esc_html__( 'Counter Section', 'juju-blog-pro' ),
            'sponsor'               => esc_html__( 'Sponsor Section', 'juju-blog-pro' ),
            'blog_events'           => esc_html__( 'Blog Events Section', 'juju-blog-pro' ),
            'special_events'        => esc_html__( 'Special Events Section', 'juju-blog-pro' ),
            'service'               => esc_html__( 'Service Section', 'juju-blog-pro' ),
            'testimonial'           => esc_html__( 'Testimonial Section', 'juju-blog-pro' ),
            'contact'               => esc_html__( 'Contact Section', 'juju-blog-pro' ),
        );
        return apply_filters( 'juju_blog_pro_sortable_sections', $sections );
    }
endif;

if ( ! function_exists( 'juju_blog_pro_top_destination_content_type' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function juju_blog_pro_top_destination_content_type() {
        $juju_blog_pro_top_destination_content_type = array(
            'page'      => esc_html__( 'Page', 'juju-blog-pro' ),
            'post'      => esc_html__( 'Post', 'juju-blog-pro' ),
            'category'  => esc_html__( 'Category', 'juju-blog-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $juju_blog_pro_top_destination_content_type = array_merge( $juju_blog_pro_top_destination_content_type, array(
                'trip'          => esc_html__( 'Trip', 'juju-blog-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'juju-blog-pro' ),
                'destination'   => esc_html__( 'Destination', 'juju-blog-pro' ),
                'activity'      => esc_html__( 'Activity', 'juju-blog-pro' ),
                ) );
        }

        $output = apply_filters( 'juju_blog_pro_top_destination_content_type', $juju_blog_pro_top_destination_content_type );

        return $output;
    }
endif;

if ( ! function_exists( 'juju_blog_pro_gallery_content_type' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function juju_blog_pro_gallery_content_type() {
        $juju_blog_pro_gallery_content_type = array(
            'page'      => esc_html__( 'Page', 'juju-blog-pro' ),
            'post'      => esc_html__( 'Post', 'juju-blog-pro' ),
            'category'  => esc_html__( 'Category', 'juju-blog-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $juju_blog_pro_gallery_content_type = array_merge( $juju_blog_pro_gallery_content_type, array(
                'trip'          => esc_html__( 'Trip', 'juju-blog-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'juju-blog-pro' ),
                'destination'   => esc_html__( 'Destination', 'juju-blog-pro' ),
                'activity'      => esc_html__( 'Activity', 'juju-blog-pro' ),
                ) );
        }

        $output = apply_filters( 'juju_blog_pro_gallery_content_type', $juju_blog_pro_gallery_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'juju_blog_pro_upcomming_event_content_type' ) ) :
    /**
     * Special Offer Options
     * @return array site event options
     */
    function juju_blog_pro_upcomming_event_content_type() {
        $juju_blog_pro_upcomming_event_content_type = array(
            'page'      => esc_html__( 'Page', 'juju-blog-pro' ),
            'post'      => esc_html__( 'Post', 'juju-blog-pro' ),
            'category'  => esc_html__( 'Category', 'juju-blog-pro' ),
        );

        if ( class_exists( 'TP_Education' ) ) {
            $juju_blog_pro_upcomming_event_content_type = array_merge( $juju_blog_pro_upcomming_event_content_type, array(
                'event'   => esc_html__( 'Event', 'juju-blog-pro' ),
                'event-category'   => esc_html__( 'Event Category', 'juju-blog-pro' ),
                ) );
        }

        $output = apply_filters( 'juju_blog_pro_upcomming_event_content_type', $juju_blog_pro_upcomming_event_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'juju_blog_pro_event_slider_content_type' ) ) :
    /**
     * Special Offer Options
     * @return array site event options
     */
    function juju_blog_pro_event_slider_content_type() {
        $juju_blog_pro_event_slider_content_type = array(
            'page'      => esc_html__( 'Page', 'juju-blog-pro' ),
            'post'      => esc_html__( 'Post', 'juju-blog-pro' ),
            'category'  => esc_html__( 'Category', 'juju-blog-pro' ),
        );

        if ( class_exists( 'TP_Education' ) ) {
            $juju_blog_pro_event_slider_content_type = array_merge( $juju_blog_pro_event_slider_content_type, array(
                'event'   => esc_html__( 'Event', 'juju-blog-pro' ),
                'event-category'   => esc_html__( 'Event Category', 'juju-blog-pro' ),
                ) );
        }

        $output = apply_filters( 'juju_blog_pro_event_slider_content_type', $juju_blog_pro_event_slider_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'juju_blog_pro_special_events_content_type' ) ) :
    /**
     * Special Offer Options
     * @return array site event options
     */
    function juju_blog_pro_special_events_content_type() {
        $juju_blog_pro_special_events_content_type = array(
            'page'      => esc_html__( 'Page', 'juju-blog-pro' ),
            'post'      => esc_html__( 'Post', 'juju-blog-pro' ),
            'category'  => esc_html__( 'Category', 'juju-blog-pro' ),
        );

        if ( class_exists( 'TP_Education' ) ) {
            $juju_blog_pro_special_events_content_type = array_merge( $juju_blog_pro_special_events_content_type, array(
                'event'   => esc_html__( 'Event', 'juju-blog-pro' ),
                'event-category'   => esc_html__( 'Event Category', 'juju-blog-pro' ),
                ) );
        }

        $output = apply_filters( 'juju_blog_pro_special_events_content_type', $juju_blog_pro_special_events_content_type );


        return $output;
    }
endif;

/**
 * List of audio for post choices.
 * @return Array Array of post ids and name.
 */
function juju_blog_pro_audio_choices() {
    $posts = get_posts( array( 'numberposts' => -1, 'post_type' => 'attachment', 'post_mime_type' => 'audio' ) );
    $choices = array();
    $choices[0] = esc_html__( '--None--', 'juju-blog-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}