<?php
/**
 * Blog Events section
 *
 * This is the template for the content of blog_events section
 *
 * @package Theme Palace
 * @subpackage Juju Blog Pro
 * @since Juju Blog Pro 1.0.0
 */
if ( ! function_exists( 'juju_blog_pro_add_blog_events_section' ) ) :
    /**
    * Add blog_events section
    *
    *@since Juju Blog Pro 1.0.0
    */
    function juju_blog_pro_add_blog_events_section() {
    	$options = juju_blog_pro_get_theme_options();
        // Check if blog_events is enabled on frontpage
        $blog_events_enable = apply_filters( 'juju_blog_pro_section_status', true, 'blog_events_section_enable' );

        if ( true !== $blog_events_enable ) {
            return false;
        }
        // Get blog_events section details
        $section_details = array();
        $section_details = apply_filters( 'juju_blog_pro_filter_blog_events_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        juju_blog_pro_render_blog_events_section( $section_details );

    }
endif;

if ( ! function_exists( 'juju_blog_pro_get_blog_events_section_details' ) ) :
    /**
    * blog_events section details.
    *
    * @since Juju Blog Pro 1.0.0
    * @param array $input blog_events section details.
    */
    function juju_blog_pro_get_blog_events_section_details( $input ) {
        $options = juju_blog_pro_get_theme_options();

        // Content type.
        $blog_events_content_type  = $options['blog_events_content_type'];
        $blog_events_count = ! empty( $options['blog_events_count'] ) ? $options['blog_events_count'] : 3;
        
        $content = array();
        switch ( $blog_events_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $blog_events_count; $i++ ) {
                    if ( ! empty( $options['blog_events_content_page_' . $i] ) )
                        $page_ids[] = $options['blog_events_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $blog_events_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $blog_events_count; $i++ ) {
                    if ( ! empty( $options['blog_events_content_post_' . $i] ) )
                        $post_ids[] = $options['blog_events_content_post_' . $i];
                }
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $blog_events_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['blog_events_content_category'] ) ? $options['blog_events_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $blog_events_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['excerpt']   = juju_blog_pro_trim_content( $options['blog_events_excerpt_length'] );
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// blog_events section content details.
add_filter( 'juju_blog_pro_filter_blog_events_section_details', 'juju_blog_pro_get_blog_events_section_details' );


if ( ! function_exists( 'juju_blog_pro_render_blog_events_section' ) ) :
  /**
   * Start blog_events section
   *
   * @return string blog_events content
   * @since Juju Blog Pro 1.0.0
   *
   */
   function juju_blog_pro_render_blog_events_section( $content_details = array() ) {
        $options = juju_blog_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="juju_blog_pro_blog_events_section" class="relative page-section">
                <div class="wrapper">
                <?php if( !empty( $options['blog_events_title'] ) ): ?>
                    <div class="section-header">
                        <h2 class="section-title"><?php echo esc_html( $options['blog_events_title'] ); ?></h2>
                    </div><!-- .section-header -->
                <?php endif; ?>
                    <div class="section-content col-3">
                        
                        <?php foreach ($content_details as $content ): ?>

                            <article>
                            <div class="post-wrapper">
                                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ) ?>');">
                                    <div class="date">
                                        <span class="day"><?php echo get_the_time('d', $content['id'] ); ?></span>
                                        <span class="month"><?php echo get_the_time('M', $content['id'] ); ?></span>
                                    </div>
                                </div><!-- .featured-image -->

                                <div class="entry-container">
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>" tabindex="0"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                        <span class="event-location"><?php the_category( '', '', $content['id'] ); ?></span>
                                    </header>

                                    <div class="entry-content">
                                        <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                    </div><!-- .entry-content -->
                                </div><!-- .entry-container -->
                            </div>
                        </article>
                            
                        <?php endforeach; ?>

                    </div>
                </div>
            </div>

    <?php }
endif;