<?php
/**
 * Banner section
 *
 * This is the template for the content of contact section
 *
 * @package Theme Palace
 * @subpackage  Juju Blog Pro
 * @since  Juju Blog Pro 1.0.0
 */
if ( ! function_exists( 'juju_blog_pro_add_contact_section' ) ) :
    /**
    * Add contact section
    *
    *@since  Juju Blog Pro 1.0.0
    */
    function juju_blog_pro_add_contact_section() {
    	$options = juju_blog_pro_get_theme_options();
        // Check if contact is enabled on frontpage
        $contact_enable = apply_filters( 'juju_blog_pro_section_status', true, 'contact_section_enable' );

        if ( true !== $contact_enable ) {
            return false;
        }
        // Get contact section details
        $section_details = array();
        $section_details = apply_filters( 'juju_blog_pro_filter_contact_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return ;
        }

        // Render contact section now.
        juju_blog_pro_render_contact_section( $section_details );
    }
endif;

if ( ! function_exists( 'juju_blog_pro_get_contact_section_details' ) ) :
    /**
    * contact section details.
    *
    * @since  Juju Blog Pro 1.0.0
    * @param array $input contact section details.
    */
    function juju_blog_pro_get_contact_section_details( $input ) {
        $options = juju_blog_pro_get_theme_options();

        $content = array();
        $content['contact_map_shortcode']       = (!empty($options['contact_map_shortcode'])) ? $options['contact_map_shortcode'] : '';
        $content['contact_section_shortcode']   = (!empty($options['contact_section_shortcode'])) ? $options['contact_section_shortcode'] : '';
        $content['contact_section_title']       = (!empty($options['contact_section_title'])) ? $options['contact_section_title'] : esc_html__('Contact Us', 'juju-blog-pro');

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// contact section content details.
add_filter( 'juju_blog_pro_filter_contact_section_details', 'juju_blog_pro_get_contact_section_details' );


if ( ! function_exists( 'juju_blog_pro_render_contact_section' ) ) :
  /**
   * Start contact section
   *
   * @return string contact content
   * @since  Juju Blog Pro 1.0.0
   *
   */
   function juju_blog_pro_render_contact_section( $content_details = array() ) {
        $options        = juju_blog_pro_get_theme_options();
        
        if ( empty( $content_details ) ) {
            return;
        } ?>
       
        <div id="juju_blog_pro_contact_section" class="relative page-section">
                <div class="wrapper">
                <?php if( !empty( $content_details['contact_section_title'] ) ): ?>
                    <div class="section-header">
                        <h2 class="section-title"><?php echo esc_html( $content_details['contact_section_title'] ); ?></h2>
                    </div><!-- .section-header -->
                <?php endif; ?>
                    <div class="section-content col-2">
                        <article>
                           <?php echo do_shortcode( wp_kses_post( $content_details['contact_map_shortcode'] ) );  ?>
                        </article>
                        <article>
                            <div class="contact-address clear">
                                <div class="widget widget_contact_info">
                                    <ul>
                                    <?php if( !empty( $options['contact_number'] ) ): ?>
                                        <li>
                                            <div class="icon">
                                                <?php echo juju_blog_pro_get_svg( array( 'icon' => 'phone') ); ?>
                                            </div>
                                            <div class="details">
                                                <span class="phone"><a href="tel:<?php echo esc_attr($options['contact_number']); ?>"><?php echo esc_html($options['contact_number']); ?><</a></span>
                                            </div><!-- .details -->
                                        </li>

                                    <?php endif;

                                        if( !empty( $options['contact_email'] ) ):

                                     ?>

                                        <li>
                                            <div class="icon">
                                               <?php echo juju_blog_pro_get_svg( array( 'icon' => 'message') ); ?>
                                            </div>
                                            <div class="details">
                                                <span class="message"><a href="mailto:<?php echo esc_attr($options['contact_email']); ?>"><?php echo esc_html($options['contact_email']); ?></a></span>
                                            </div><!-- .details -->
                                        </li> 

                                    <?php endif;

                                        if( !empty( $options['contact_address'] ) ):
                                     ?>

                                        <li>
                                            <div class="icon">
                                               <?php echo juju_blog_pro_get_svg( array( 'icon' => 'map') ); ?>
                                            </div><!-- .icon -->
                                            <div class="details">
                                                <span class="address"><?php echo esc_html($options['contact_address']); ?></span>
                                            </div><!-- .details -->
                                        </li>
                                    <?php endif; ?>

                                    </ul>
                                </div><!-- .widget -->
                            </div>

                            <?php echo do_shortcode( wp_kses_post( $content_details['contact_section_shortcode'] ) );  ?>
                        </article>
                    </div>
                </div>
            </div>

<?php    }    
endif;