<?php
/**
 * Event Slider section
 *
 * This is the template for the content of event_slider section
 *
 * @package Theme Palace
 * @subpackage Juju Blog Pro
 * @since Juju Blog Pro 1.0.0
 */
if ( ! function_exists( 'juju_blog_pro_add_event_slider_section' ) ) :
    /**
    * Add event_slider section
    *
    *@since Juju Blog Pro 1.0.0
    */
    function juju_blog_pro_add_event_slider_section() {
    	$options = juju_blog_pro_get_theme_options();
        // Check if event_slider is enabled on frontpage
        $event_slider_enable = apply_filters( 'juju_blog_pro_section_status', true, 'event_slider_section_enable' );

        if ( true !== $event_slider_enable ) {
            return false;
        }
        // Get event_slider section details
        $section_details = array();
        $section_details = apply_filters( 'juju_blog_pro_filter_event_slider_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        juju_blog_pro_render_event_slider_section( $section_details );

    }
endif;

if ( ! function_exists( 'juju_blog_pro_get_event_slider_section_details' ) ) :
    /**
    * event_slider section details.
    *
    * @since Juju Blog Pro 1.0.0
    * @param array $input event_slider section details.
    */
    function juju_blog_pro_get_event_slider_section_details( $input ) {
        $options = juju_blog_pro_get_theme_options();

        // Content type.
        $event_slider_content_type  = $options['event_slider_content_type'];
        $event_slider_count = ! empty( $options['event_slider_count'] ) ? $options['event_slider_count'] : 3;
        
        $content = array();
        switch ( $event_slider_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $event_slider_count; $i++ ) {
                    if ( ! empty( $options['event_slider_content_page_' . $i] ) )
                        $page_ids[] = $options['event_slider_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $event_slider_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $event_slider_count; $i++ ) {
                    if ( ! empty( $options['event_slider_content_post_' . $i] ) )
                        $post_ids[] = $options['event_slider_content_post_' . $i];
                }
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $event_slider_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['event_slider_content_category'] ) ? $options['event_slider_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $event_slider_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'event':
                $page_ids = array();

                for ( $i = 1; $i <= $event_slider_count; $i++ ) {
                    if ( ! empty( $options['event_slider_content_event_' . $i] ) )
                        $page_ids[] = $options['event_slider_content_event_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'tp-event',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $event_slider_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'event-category':
                $cat_id = ! empty( $options['event_slider_content_event_category'] ) ? $options['event_slider_content_event_category'] : '';
                $args = array(
                    'post_type'      => 'tp-event',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'tp-event-category',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $event_slider_count ),
                    );                    
            break;

            default:
            break;
        }

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['excerpt']   = juju_blog_pro_trim_content( $options['event_slider_excerpt_length'] );
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// event_slider section content details.
add_filter( 'juju_blog_pro_filter_event_slider_section_details', 'juju_blog_pro_get_event_slider_section_details' );


if ( ! function_exists( 'juju_blog_pro_render_event_slider_section' ) ) :
  /**
   * Start event_slider section
   *
   * @return string event_slider content
   * @since Juju Blog Pro 1.0.0
   *
   */
   function juju_blog_pro_render_event_slider_section( $content_details = array() ) {
        $options = juju_blog_pro_get_theme_options();
        $event_slider_autoplay = ($options['event_slider_autoplay']) ? 'true' : 'false';

        $event_slider_content_type  = $options['event_slider_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="juju_blog_pro_event_slider_section" class="page-section same-background">
                <div class="featured-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 800, "dots": true, "arrows":true, "autoplay": <?php echo esc_attr( $event_slider_autoplay ); ?>, "draggable": true, "fade": false, "adaptiveHeight": true }'>
                    
                <?php foreach ($content_details as $content ): ?>
                    
                    <article style="background-image:url('<?php echo esc_url( $content['image'] ); ?>');">
                        <div class="overlay"></div>
                        <div class="wrapper">
                            <div class="featured-content-wrapper">
                                <div class="entry-container">
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>
                                    <div class="entry-content">
                                        <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                    </div>
                                </div><!-- .entry-container -->
                                <div class="entry-meta">
                                <?php if ( ! in_array( $event_slider_content_type, array( 'event', 'event-category' ) ) ) { ?>
                                    <?php juju_blog_pro_posted_on( $content['id'] ); ?><!-- .posted-on -->
                                <?php }else{
                                        tp_event_date( $content['id'] );
                                    } ?>
                                </div>

                                <div class="read-more">
                                
                                <?php if( !empty( $options['event_slider_primary_btn'] ) ): ?>
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn primary"><?php echo esc_html( $options['event_slider_primary_btn'] ); ?></a>
                                <?php endif; ?>

                                <?php if( !empty( $options['event_slider_btn_link'] ) && !empty( $options['event_slider_secondary_btn'] ) ): ?>

                                    <a href="<?php echo esc_url( $options['event_slider_btn_link'] ); ?>" class="btn secondary"><?php echo esc_html( $options['event_slider_secondary_btn'] ); ?></a>

                                <?php endif; ?>

                                </div>
                            </div><!-- .featured-content-wrapper -->
                        </div>
                    </article>

                <?php endforeach; ?>
                    
                </div><!-- .featured-slider -->
            </div>

    <?php }
endif;