<?php
/**
 * Music Gallery section
 *
 * This is the template for the content of music_gallery section
 *
 * @package Theme Palace
 * @subpackage Juju Blog Pro
 * @since Juju Blog Pro 1.0.0
 */
if ( ! function_exists( 'juju_blog_pro_add_music_gallery_section' ) ) :
    /**
    * Add music_gallery section
    *
    *@since Juju Blog Pro 1.0.0
    */
    function juju_blog_pro_add_music_gallery_section() {
    	$options = juju_blog_pro_get_theme_options();
        // Check if music_gallery is enabled on frontpage
        $music_gallery_enable = apply_filters( 'juju_blog_pro_section_status', true, 'music_gallery_section_enable' );

        if ( true !== $music_gallery_enable ) {
            return false;
        }
        // Get music_gallery section details
        $section_details = array();
        $section_details = apply_filters( 'juju_blog_pro_filter_music_gallery_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        juju_blog_pro_render_music_gallery_section( $section_details );
    
    }
endif;

if ( ! function_exists( 'juju_blog_pro_get_music_gallery_section_details' ) ) :
    /**
    * music_gallery section details.
    *
    * @since Juju Blog Pro 1.0.0
    * @param array $input music_gallery section details.
    */
    function juju_blog_pro_get_music_gallery_section_details( $input ) {
        $options = juju_blog_pro_get_theme_options();

        // Content type.
        $music_gallery_content_type  = $options['music_gallery_content_type'];
        $music_gallery_count = ! empty( $options['music_gallery_count'] ) ? $options['music_gallery_count'] : 9;
        
        $content = array();
        switch ( $music_gallery_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $music_gallery_count; $i++ ) {
                    if ( ! empty( $options['music_gallery_content_page_' . $i] ) )
                        $page_ids[] = $options['music_gallery_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $music_gallery_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $music_gallery_count; $i++ ) {
                    if ( ! empty( $options['music_gallery_content_post_' . $i] ) )
                        $post_ids[] = $options['music_gallery_content_post_' . $i];
                }
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $music_gallery_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['music_gallery_content_category'] ) ? $options['music_gallery_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $music_gallery_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// music_gallery section content details.
add_filter( 'juju_blog_pro_filter_music_gallery_section_details', 'juju_blog_pro_get_music_gallery_section_details' );


if ( ! function_exists( 'juju_blog_pro_render_music_gallery_section' ) ) :
  /**
   * Start music_gallery section
   *
   * @return string music_gallery content
   * @since Juju Blog Pro 1.0.0
   *
   */
   function juju_blog_pro_render_music_gallery_section( $content_details = array() ) {
        $options = juju_blog_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="juju_blog_pro_music_gallery_section" class="relative page-section">
                <div class="wrapper">
                <?php if ( !empty( $options['music_gallery_title'] ) ): ?>

                    <div class="section-header">
                        <h2 class="section-title"><?php echo esc_html( $options['music_gallery_title'] ); ?></h2>
                    </div><!-- .section-header -->
                    
                <?php endif; ?>

                    <div class="section-content col-3 clear">
                        
                        <?php foreach ($content_details as $content ): ?>

                            <article>
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>
                            </div><!-- .featured-image -->
                        </article>
                            
                        <?php endforeach; ?>

                    </div><!-- .col-3 -->
                </div><!-- .wrapper -->
            </div>

    <?php }
endif;