<?php
/**
 * Playlist section
 *
 * This is the template for the content of playlist section
 *
 * @package Theme Palace
 * @subpackage Juju Blog Pro
 * @since Juju Blog Pro 1.0.0
 */
if ( ! function_exists( 'juju_blog_pro_add_playlist_section' ) ) :
    /**
    * Add playlist section
    *
    *@since Juju Blog Pro 1.0.0
    */
    function juju_blog_pro_add_playlist_section() {
    	$options = juju_blog_pro_get_theme_options();
        // Check if playlist is enabled on frontpage
        $playlist_enable = apply_filters( 'juju_blog_pro_section_status', true, 'playlist_section_enable' );

        if ( true !== $playlist_enable ) {
            return false;
        }

        // Render playlist section now.
        juju_blog_pro_render_playlist_section();
    }
endif;

if ( ! function_exists( 'juju_blog_pro_render_playlist_section' ) ) :
  /**
   * Start playlist section
   *
   * @return string playlist content
   * @since Juju Blog Pro 1.0.0
   *
   */
   function juju_blog_pro_render_playlist_section() {
        $options = juju_blog_pro_get_theme_options();
        $playlist = ! empty( $options['playlist_content'] ) ? $options['playlist_content'] : array();
        $image = ! empty( $options['playlist_bg_image'] ) ? $options['playlist_bg_image'] : '';
        $playlist_image = ! empty( $options['playlist_title'] ) ? $options['playlist_title'] : '';
        
        if ( empty( $playlist ) )
            return;

        ?>

        <div id="juju_blog_pro_playlist_section" class="relative page-section" style="background-image: url('<?php echo esc_url( $image ); ?>');">
          <div class="overlay"></div>
          <div class="wrapper">
            <?php if( !empty( $playlist_image ) ): ?>
              <div class="section-header">
                <h2 class="section-title"><?php echo esc_html( $playlist_image ); ?></h2>
              </div>
            <?php endif; ?>

            <?php 
            if ( ! empty( $playlist ) ) :
              $playlist = implode(',', $playlist); ?>

            <div class="playlist"> 

              <?php 
              $playlist_shortcode = '[playlist type="audio" ids="' . $playlist . '" style="light"]';
              echo do_shortcode( wp_kses_post( $playlist_shortcode ) );  
              ?>

            </div>
          <?php endif; ?>
        </div>
      </div>

    <?php }
endif;