<?php
/**
 * Special Events section
 *
 * This is the template for the content of special_events section
 *
 * @package Theme Palace
 * @subpackage Juju Blog Pro
 * @since Juju Blog Pro 1.0.0
 */
if ( ! function_exists( 'juju_blog_pro_add_special_events_section' ) ) :
    /**
    * Add special_events section
    *
    *@since Juju Blog Pro 1.0.0
    */
    function juju_blog_pro_add_special_events_section() {
    	$options = juju_blog_pro_get_theme_options();
        // Check if special_events is enabled on frontpage
        $special_events_enable = apply_filters( 'juju_blog_pro_section_status', true, 'special_events_section_enable' );

        if ( true !== $special_events_enable ) {
            return false;
        }
        // Get special_events section details
        $section_details = array();
        $section_details = apply_filters( 'juju_blog_pro_filter_special_events_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        juju_blog_pro_render_special_events_section( $section_details );

    }
endif;

if ( ! function_exists( 'juju_blog_pro_get_special_events_section_details' ) ) :
    /**
    * special_events section details.
    *
    * @since Juju Blog Pro 1.0.0
    * @param array $input special_events section details.
    */
    function juju_blog_pro_get_special_events_section_details( $input ) {
        $options = juju_blog_pro_get_theme_options();

        // Content type.
        $special_events_content_type  = $options['special_events_content_type'];
        $special_events_count = ! empty( $options['special_events_count'] ) ? $options['special_events_count'] : 4;
        
        $content = array();
        switch ( $special_events_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $special_events_count; $i++ ) {
                    if ( ! empty( $options['special_events_content_page_' . $i] ) )
                        $page_ids[] = $options['special_events_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $special_events_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $special_events_count; $i++ ) {
                    if ( ! empty( $options['special_events_content_post_' . $i] ) )
                        $post_ids[] = $options['special_events_content_post_' . $i];
                }
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $special_events_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['special_events_content_category'] ) ? $options['special_events_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $special_events_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'event':
                $page_ids = array();

                for ( $i = 1; $i <= $special_events_count; $i++ ) {
                    if ( ! empty( $options['special_events_content_special_events_' . $i] ) )
                        $page_ids[] = $options['special_events_content_special_events_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'tp-event',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $special_events_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'event-category':
                $cat_id = ! empty( $options['special_events_content_special_events_category'] ) ? $options['special_events_content_special_events_category'] : '';
                $args = array(
                    'post_type'      => 'tp-event',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'tp-event-category',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $special_events_count ),
                    );                    
            break;

            default:
            break;
        }

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['excerpt']   = juju_blog_pro_trim_content( $options['special_events_excerpt_length'] );
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// special_events section content details.
add_filter( 'juju_blog_pro_filter_special_events_section_details', 'juju_blog_pro_get_special_events_section_details' );


if ( ! function_exists( 'juju_blog_pro_render_special_events_section' ) ) :
  /**
   * Start special_events section
   *
   * @return string special_events content
   * @since Juju Blog Pro 1.0.0
   *
   */
   function juju_blog_pro_render_special_events_section( $content_details = array() ) {
        $options = juju_blog_pro_get_theme_options();

        $special_events_content_type  = $options['special_events_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="juju_blog_pro_special_events_section" class="relative page-section">
                <div class="wrapper">
                <?php if( !empty( $options['special_events_title'] ) ): ?>
                    <div class="section-header">
                        <h2 class="section-title"><?php echo esc_html( $options['special_events_title'] ); ?></h2>
                    </div><!-- .section-header -->
                <?php endif; ?>

                    <div class="section-content clear">
                        
                    <?php foreach ($content_details as $content ): ?>

                        <article>
                            <div class="event-wrapper">
                                <div class="entry-container">
                                <?php if ( !in_array( $special_events_content_type, array( 'event', 'event-category' ) ) ) { ?>
                                    <?php juju_blog_pro_posted_on( $content['id'] ); ?>
                                <?php }else{
                                    tp_event_date( $content['id'] );
                                }

                                 ?>

                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>

                                    <div class="entry-content">
                                        <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                    </div><!-- .entry-content -->
                                </div><!-- .entry-container -->
                            </div><!-- .event-wrapper -->
                        </article>
                        
                    <?php endforeach; ?>

                    </div><!-- .col-2 -->
                </div><!-- .wrapper -->
            </div>

    <?php }
endif;