<?php
/**
 * Stories section
 *
 * This is the template for the content of Stories section
 *
 * @package Theme Palace
 * @subpackage  Juju Blog Pro
 * @since  Juju Blog Pro 1.0.0
 */
if ( ! function_exists( 'juju_blog_pro_add_stories_section' ) ) :
    /**
    * Add top stories section
    *
    *@since  Juju Blog Pro 1.0.0
    */
    function juju_blog_pro_add_stories_section() {
        $options = juju_blog_pro_get_theme_options();
        // Check if top stories is enabled on frontpage
        $stories_enable = apply_filters( 'juju_blog_pro_section_status', true, 'stories_section_enable' );

        if ( true !== $stories_enable ) {
            return false;
        }
        // Get top stories section details
        $section_details = array();
        $section_details = apply_filters( 'juju_blog_pro_filter_stories_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }
        // Render top stories section now.
        juju_blog_pro_render_stories_section( $section_details );
    }
endif;

if ( ! function_exists( 'juju_blog_pro_get_stories_section_details' ) ) :
    /**
    * top stories section details.
    *
    * @since  Juju Blog Pro 1.0.0
    * @param array $input top stories section details.
    */
    function juju_blog_pro_get_stories_section_details( $input ) {
        $options = juju_blog_pro_get_theme_options();

        $cat_ids = ! empty( $options['stories_content_category'] ) ? $options['stories_content_category'] : array();
        if ( empty( $cat_ids ) )
            return;
        $args = array();
        $content = array();
        foreach ( $cat_ids as $cat_id ) {

            $args = array(
                'post_type'             => 'post',
                'posts_per_page'        => absint( 5 ),
                'cat'                   => absint( $cat_id ),
                'ignore_sticky_posts'   => true,
            );                    

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                $cat_posts['details'] = array();
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'medium_large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';
                    // Push to the main array.
                    array_push( $cat_posts['details'], $page_post );
                endwhile;
                $cat_posts['cat_id'] = $cat_id;
                array_push( $content, $cat_posts );
            endif;
            wp_reset_postdata();
        }

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;

// top stories section content details.
add_filter( 'juju_blog_pro_filter_stories_section_details', 'juju_blog_pro_get_stories_section_details' );

if ( ! function_exists( 'juju_blog_pro_render_stories_section' ) ) :
  /**
   * Start top stories section
   *
   * @return string top stories content
   * @since  Juju Blog Pro 1.0.0
   *
   */
   function juju_blog_pro_render_stories_section( $content_details = array() ) {
        $options = juju_blog_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
            
            <div id="juju_blog_pro_top_stories_section" class="page-section same-background">
                <div class="wrapper title-wrapper">

                <?php if( !empty( $options['stories_title'] ) ): ?>

                    <div class="section-header">
                        <h2 class="section-title"><?php echo esc_html( $options['stories_title'] ); ?></h2>
                    </div><!-- .section-header -->

                <?php endif; ?>

                    <ul class="tabs">
                        <?php foreach ( $content_details as $i=>$content ):
                        $terms = get_term( $content['cat_id'] ); 
                        if(!is_wp_error( $terms ) && $terms): ?>
                           <li><a href="#" data-tab="<?php echo $terms->slug; ?>"  <?php if($i==0) echo 'class="active"'; ?> ><?php echo $terms->name; ?></a></li>

                       <?php 
                       endif;
                       endforeach; ?>
                    </ul><!-- .tabs -->
                </div><!-- .wrapper -->

                <div class="wrapper tab-wrapper">
                    <div class="section-content">

                     <?php foreach ( $content_details as $i=>$contents ):
                     $terms = get_term( $contents['cat_id'] ); ?>
                        

                        <div id="<?php echo $terms->slug; ?>" class="tab-content <?php if( $i==0 ) echo "active"; ?> clear">
                            <div class="main-width">
                                
                                <?php $i=1; foreach ( $contents['details'] as $content ): 
                                if ( $i == 1 ){
                                ?>

                                <article>
                                    <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                        <div class="overlay"></div>
                                    </div><!-- .featured-image -->

                                    <div class="entry-container">
                                        <span class="cat-links">
                                            <?php the_category( '', '', $content['id'] ); ?>
                                        </span><!-- .cat-links -->

                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                        </header>
                                    </div>
                                </article>

                            <?php 
                        }
                            $i++; endforeach; ?>


                            </div><!-- .main-width-->

                            <div class="sub-width">
                                
                                <?php $i=1; foreach ( $contents['details'] as $content ): 
                                if ( $i !== 1 ){
                                ?>

                                <article>
                                    <div class="top-stories-post-wrapper">
                                        <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                            <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                                        </div><!-- .featured-image -->

                                        <div class="entry-container">
                                            <span class="cat-links">
                                                <?php the_category( '', '', $content['id'] ); ?>
                                            </span><!-- .cat-links -->

                                            <header class="entry-header">
                                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                            </header>
                                        </div><!-- .entry-container -->
                                    </div>
                                </article>

                                <?php 
                        }
                            $i++; endforeach; ?>
                               
                            </div><!-- .sub-width-->
                        </div><!-- .tab-content -->

                        <?php endforeach; ?>


                    </div><!-- .section-content -->
                </div>
            </div>

    <?php }
endif;  ?>

