<?php
/**
 * Subscription section
 *
 * This is the template for the content of subscription section
 *
 * @package Theme Palace
 * @subpackage Juju Blog Pro
 * @since Juju Blog Pro 1.0.0
 */
if ( ! function_exists( 'juju_blog_pro_add_subscription_section' ) ) :
    /**
    * Add subscription section
    *
    *@since Juju Blog Pro 1.0.0
    */
    function juju_blog_pro_add_subscription_section() {
        $options = juju_blog_pro_get_theme_options();

        // Check if subscription is enabled on frontpage
        $subscription_enable = apply_filters( 'juju_blog_pro_section_status', true, 'subscription_section_enable' );
        
        if ( true !== $subscription_enable ) {
           return false;
        }

        // Render subscription section now.
        juju_blog_pro_render_subscription_section();
    }
endif;

if ( ! function_exists( 'juju_blog_pro_render_subscription_section' ) ) :
  /**
   * Start subscription section
   *
   * @return string subscription content
   * @since Juju Blog Pro 1.0.0
   *    
   */
function juju_blog_pro_render_subscription_section() {
    if ( ! class_exists( 'Jetpack' ) ) {
       return;
    } elseif ( class_exists( 'Jetpack' ) ) {
        if ( ! Jetpack::is_module_active( 'subscriptions' ) )
           return;
    }
    $options = juju_blog_pro_get_theme_options();

    $subscription_title             = ! empty( $options['subscription_title'] ) ? $options['subscription_title'] : '';
    $subscription_description       = ! empty( $options['subscription_description'] ) ? $options['subscription_description'] : '';
    $subscription_btn_title         = ! empty( $options['subscription_btn_title'] ) ? $options['subscription_btn_title'] : esc_html__( 'Subscribe Now', 'juju-blog-pro' );
 ?>

         <div id="juju_blog_pro_subscribe_now_section" class="relative page-section">
            <div class="wrapper">
                <div class="subscribe-now-wrapper">
                    <article>
                        <div class="entry-container">
                            <div class="section-header">
                                <?php if( !empty( $subscription_title ) ): ?>
                                    <h2 class="section-title"><?php echo esc_html($subscription_title); ?></h2>
                                <?php endif; ?>

                                <?php if( !empty( $subscription_description ) ): ?>
                                    <div id="subscribe-text">
                                        <p><?php echo esc_html($subscription_description); ?></p>
                                    </div>
                                <?php endif; ?>
                            </div><!-- .section-header -->

                            <div class="subscribe-form-wrapper">
                                <?php 
                                $subscription_shortcode = '[jetpack_subscription_form title="" subscribe_text="" subscribe_button="' . esc_html( $subscription_btn_title ) . '" show_subscribers_total="0"]';
                                echo do_shortcode( wp_kses_post( $subscription_shortcode ) ); 
                                ?>
                            </div><!-- .subscribe-form-wrapper -->
                        </div>
                    </article>
                </div><!-- subscribe-now-wrapper -->
            </div><!-- .wrapper -->
        </div>
    
    <?php }
endif;