<?php
/**
 * team section
 *
 * This is the template for the content of team section
 *
 * @package Theme Palace
 * @subpackage Juju Blog Pro
 * @since Juju Blog Pro 1.0.0
 */
if ( ! function_exists( 'juju_blog_pro_add_team_section' ) ) :
    /**
    * Add team section
    *
    *@since Juju Blog Pro 1.0.0
    */
    function juju_blog_pro_add_team_section() {
    	$options = juju_blog_pro_get_theme_options();
        // Check if team is enabled on frontpage
        $team_enable = apply_filters( 'juju_blog_pro_section_status', true, 'team_section_enable' );

        if ( true !== $team_enable ) {
            return false;
        }
        // Get team section details
        $section_details = array();
        $section_details = apply_filters( 'juju_blog_pro_filter_team_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render team section now.
        juju_blog_pro_render_team_section( $section_details );
    }
endif;

if ( ! function_exists( 'juju_blog_pro_get_team_section_details' ) ) :
    /**
    * team section details.
    *
    * @since Juju Blog Pro 1.0.0
    * @param array $input team section details.
    */
    function juju_blog_pro_get_team_section_details( $input ) {
        $options = juju_blog_pro_get_theme_options();

        // Content type.
        $team_content_type  = $options['team_content_type'];
        $team_count = ! empty( $options['team_count'] ) ? $options['team_count'] : 3;
        
        $content = array();
        switch ( $team_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $team_count; $i++ ) {
                    if ( ! empty( $options['team_content_page_' . $i] ) ) :
                        $page_ids[] = $options['team_content_page_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $team_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $team_count; $i++ ) {
                    if ( ! empty( $options['team_content_post_' . $i] ) ) :
                        $post_ids[] = $options['team_content_post_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $team_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['team_content_category'] ) ? $options['team_content_category'] : '';

                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $team_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                $i = 1;
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                     $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';
                    $page_post['social']    = (! empty( $options['team_social_' . $i] ) ) ? $options['team_social_' . $i] : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                    $i++;
                endwhile;
            endif;
            wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// team section content details.
add_filter( 'juju_blog_pro_filter_team_section_details', 'juju_blog_pro_get_team_section_details' );


if ( ! function_exists( 'juju_blog_pro_render_team_section' ) ) :
  /**
   * Start team section
   *
   * @return string team content
   * @since Juju Blog Pro 1.0.0
   *
   */
function juju_blog_pro_render_team_section( $content_details = array() ) {
    $options = juju_blog_pro_get_theme_options();

    if ( empty( $content_details ) ) {
        return;
} ?>

 <div id="juju_blog_pro_team_section" class="relative page-section">
                <div class="wrapper">
                <?php if ( !empty( $options['team_title'] ) ): ?>

                    <div class="section-header">
                        <h2 class="section-title"><?php echo esc_html( $options['team_title'] ); ?></h2>
                    </div><!-- .section-header -->
                    
                <?php endif; ?>
                    

                    <div class="section-content col-3">
                        
                    <?php $i=1; foreach ($content_details as $content ): ?>

                        <article>
                            <div class="team-item-wrapper">
                                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                </div><!-- .featured-image -->

                                <div class="entry-container">
                                    <header class="entry-header">
                                    
                                    <?php if( !empty( $options['team_position_'.$i ] ) ): ?>

                                        <span class="team-position"><?php echo esc_html( $options['team_position_'.$i ] ); ?></span>
                                        
                                    <?php endif; ?>
                                        
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ) ; ?>"><?php echo esc_html( $content['title'] ) ; ?></a></h2>
                                    </header>

                                    <?php if ( ! empty( $content['social'] ) ) {
                        $social = explode( '|', $content['social'] ); ?>

                                    <div class="social-icons">
                                        <ul>
                                            <?php foreach( $social as $social_link ) : ?>
                                    <li>
                                        <a href="<?php echo esc_url( $social_link ); ?>">
                                            <?php echo juju_blog_pro_return_social_icon( $social_link ); ?>
                                        </a>
                                    </li>
                                <?php endforeach; ?>
                                        </ul>
                                    </div><!-- .social-icons -->
                                    <?php } ?>
                                </div>
                            </div>
                        </article>
                        
                    <?php $i++; endforeach; ?>

                    </div>
                </div>
            </div>
  
    <?php }
endif;