<?php
/**
 * Top Destination section
 *
 * This is the template for the content of popular Destination section
 *
 * @package Theme Palace
 * @subpackage Juju Blog Pro
 * @since Juju Blog Pro 1.0.0
 */
if ( ! function_exists( 'juju_blog_pro_add_top_destination_section' ) ) :
	/**
	* Add popular Destination section
	*
	*@since Juju Blog Pro 1.0.0
	*/
	function juju_blog_pro_add_top_destination_section() {
		$options = juju_blog_pro_get_theme_options();

			// Check if Destination is enabled on frontpage
			$top_destination_enable = apply_filters( 'juju_blog_pro_section_status', true, 'top_destination_section_enable' );
			
			if ( true !== $top_destination_enable ) {
				return false;
			}
			// Get Destination section details
			$section_details = array();
			$section_details = apply_filters( 'juju_blog_pro_filter_top_destination_section_details', $section_details );
			if ( empty( $section_details ) ) {
				return;
			}

			// Render Destination section now.
			juju_blog_pro_render_top_destination_section( $section_details );
		}
endif;

if ( ! function_exists( 'juju_blog_pro_get_top_destination_section_details' ) ) :
	/**
	* Top Destination section details.
	*
	* @since Juju Blog Pro 1.0.0
	* @param array $input popular destination section details.
	*/
	function juju_blog_pro_get_top_destination_section_details( $input ) {
		$options = juju_blog_pro_get_theme_options();

		// Content type.
		$top_destination_content_type  = $options['top_destination_content_type'];
		$top_destination_count = ! empty( $options['top_destination_count'] ) ? $options['top_destination_count'] : 4;
		
		$content 		= array();
		$args 			= array();
        $content['cats'] = array();
		switch ( $top_destination_content_type ) {
		
			case 'category':
				$cat_id = ! empty( $options['top_destination_content_category'] ) ? $options['top_destination_content_category'] : '';
				$args = array(
					'post_type'         	=> 'post',
					'posts_per_page'    	=> absint( $top_destination_count ),
					'cat'               	=> absint( $cat_id ),
					'ignore_sticky_posts'   => true,
					);                    
			break;

			case 'page':
				$page_ids = array();

				for ( $i = 1; $i <= $top_destination_count; $i++ ) {
					if ( ! empty( $options['top_destination_content_page_' . $i] ) )
						$page_ids[] = $options['top_destination_content_page_' . $i];
				}
				
				$args = array(
					'post_type'         => 'page',
					'post__in'          => ( array ) $page_ids,
					'posts_per_page'    => absint( $top_destination_count ),
					'orderby'           => 'post__in',
					);                    
			break;

			case 'post':
				$post_ids = array();

				for ( $i = 1; $i <= $top_destination_count; $i++ ) {
					if ( ! empty( $options['top_destination_content_post_' . $i] ) )
						$post_ids[] = $options['top_destination_content_post_' . $i];
				}
				$args = array(
					'post_type'         	=> 'post',
					'post__in'          	=> ( array ) $post_ids,
					'posts_per_page'    	=> absint( $top_destination_count ),
					'orderby'           	=> 'post__in',
					'ignore_sticky_posts'   => true,
					);                    
			break;

			case 'trip':
				if ( ! class_exists( 'WP_Travel' ) )
					return;

				$page_ids = array();

				for ( $i = 1; $i <= $top_destination_count; $i++ ) {
					if ( ! empty( $options['top_destination_content_trip_' . $i] ) )
						$page_ids[] = $options['top_destination_content_trip_' . $i];
				}
				
				$args = array(
					'post_type'         => 'itineraries',
					'post__in'          => ( array ) $page_ids,
					'posts_per_page'    => absint( $top_destination_count ),
					'orderby'           => 'post__in',
					);   

				$content['taxonomy'] = 'travel_locations';

			break;

			case 'trip-types': // trip-types
				if ( ! class_exists( 'WP_Travel' ) )
					return;

				$cat_id = ! empty( $options['top_destination_content_trip_types'] ) ? $options['top_destination_content_trip_types'] : array();

				$args = array(
					'post_type' => 'itineraries',
					'tax_query' => array(
						array(
							'taxonomy' => 'itinerary_types',
							'field'    => 'id',
							'terms'    => $cat_id,
						),
					),
					'posts_per_page'  => absint( $top_destination_count ),
					);

                $content['taxonomy'] = 'itinerary_types';
			break;

			
			case 'destination': //Destination
				if ( ! class_exists( 'WP_Travel' ) )
					return;

				$cat_id = ! empty( $options['top_destination_content_destination'] ) ? $options['top_destination_content_destination'] : array();
				
				$args = array(
					'post_type'      => 'itineraries',
					'tax_query' => array(
						array(
							'taxonomy' => 'travel_locations',
							'field'    => 'id',
							'terms'    => $cat_id,
						),
					),
					'posts_per_page'  => absint( $top_destination_count ),
					); 

				$content['taxonomy'] = 'travel_locations';
			break;

			case 'activity':
				if ( ! class_exists( 'WP_Travel' ) )
					return;
				
				$cat_id = ! empty( $options['top_destination_content_activity'] ) ? $options['top_destination_content_activity'] : array();
				
				if ( empty( $cat_id ) )
                    return;
				$args = array(
					'post_type'      => 'itineraries',
					'tax_query' => array(
						array(
							'taxonomy' => 'activity',
							'field'    => 'id',
							'terms'    => $cat_id,
						),
					),
					'posts_per_page'  => absint( $top_destination_count ),
					); 

                $content['taxonomy'] = 'activity';
			break;

			default:
			break;
		}

		$content['details'] = array();
		$query = new WP_Query( $args );
		if ( $query->have_posts() ) : 
			while ( $query->have_posts() ) : $query->the_post();
				$page_post['id']        = get_the_id();
				$page_post['title']     = get_the_title();
				$page_post['url']       = get_the_permalink();
				$page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) :  get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';
				// Push to the main array.
				array_push( $content['details'], $page_post );
			endwhile;
		endif;

		wp_reset_postdata();
		if ( ! empty( $content ) ) {
				$input = $content;
		}
		return $input;
	}
endif;

// Destination section content details.
add_filter( 'juju_blog_pro_filter_top_destination_section_details', 'juju_blog_pro_get_top_destination_section_details' );


if ( ! function_exists( 'juju_blog_pro_render_top_destination_section' ) ) :
	/**
	 * Start Destination section
	 *
	 * @return string Destination content
	 * @since Juju Blog Pro 1.0.0
	 *
	 */
	 function juju_blog_pro_render_top_destination_section( $content_details = array() ) {
		$options = juju_blog_pro_get_theme_options();

		$top_destination_content_type  	= $options['top_destination_content_type'];
		$top_destination_btn_label 		= !empty($options['top_destination_btn_label']) ? $options['top_destination_btn_label'] : '';

		$autoplay = ($options['top_destination_autoplay']) ? 'true' : 'false';

		$taxonomy = isset($content_details['taxonomy']) ? $content_details['taxonomy'] : 'category';

		if ( empty( $content_details ) ) {
				return;
		} ?>
		
		<div id="juju_blog_pro_top_destination_section" class="relative page-section same-background">
                <div class="wrapper">
                <?php if ( !empty( $options['top_destination_title'] ) ): ?>

                	<div class="section-header">
                        <h2 class="section-title"><?php echo esc_html($options['top_destination_title']); ?></h2>
                    </div><!-- .section-header -->
                	
                <?php endif; ?>

                    <div class="top-destination-slider" data-slick='{"slidesToShow": 3, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": false, "arrows":true, "autoplay": <?php echo esc_attr( $autoplay ); ?>, "draggable": true, "fade": false }'>
                        
                    <?php foreach ( $content_details['details'] as $content ):

                    $terms = get_the_terms( $content['id'],$taxonomy);

                     ?>

                    	<article class="has-post-thumbnail">
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'])?>');">
                                <div class="overlay"></div>

                                <?php if ( !empty( $top_destination_btn_label ) ): ?>

                                	<div class="read-more">
                                    <a href="<?php echo esc_url($content['url']); ?>" class="btn"><?php echo esc_html( $top_destination_btn_label ); ?></a>
                                </div>
                                	
                                <?php endif; ?>
                                
                            </div>
                            <div class="entry-header-wrapper clear">
                                <header class="entry-header">
                                <?php if( ! empty( $terms ) && ! is_wp_error( $terms ) ) : ?>
                                    <span class="location">
                                        <?php echo esc_html($terms[0]->name); ?>
                                    </span>
                                <?php endif; ?>
                                    <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title']); ?></a></h2>
                                </header>   
                        </article>
                    	
                    <?php endforeach; ?>
                        
                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div>

<?php }
endif;