<?php
/**
 * Topics section
 *
 * This is the template for the content of topics section
 *
 * @package Theme Palace
 * @subpackage Juju Blog Pro
 * @since Juju Blog Pro 1.0.0
 */
if ( ! function_exists( 'juju_blog_pro_add_topics_section' ) ) :
    /**
    * Add topics section
    *
    *@since Juju Blog Pro 1.0.0
    */
    function juju_blog_pro_add_topics_section() {
        $options = juju_blog_pro_get_theme_options();
        // Check if topics is enabled on frontpage
        $topics_enable = apply_filters( 'juju_blog_pro_section_status', true, 'topics_section_enable' );

        if ( true !== $topics_enable ) {
            return false;
        }
        // Get topics section details
        $section_details = array();
        $section_details = apply_filters( 'juju_blog_pro_filter_topics_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render topics section now.
        juju_blog_pro_render_topics_section( $section_details );
    }
endif;

if ( ! function_exists( 'juju_blog_pro_get_topics_section_details' ) ) :
    /**
    * topics section details.
    *
    * @since Juju Blog Pro 1.0.0
    * @param array $input topics section details.
    */
    function juju_blog_pro_get_topics_section_details( $input ) {
        $options = juju_blog_pro_get_theme_options();

        // Content type.
        $topics_content_type  = $options['topics_content_type'];
        $topics_count = !empty( $options['topics_count'] ) ? $options['topics_count'] : 6;
        $content = array();
        switch ( $topics_content_type ) {
            
            case 'page':
                $page_ids = array();
                $author = array();

                for ( $i = 1; $i <= $topics_count; $i++ ) {
                    if ( ! empty( $options['topics_content_page_' . $i] ) ) :
                        $page_ids[] = $options['topics_content_page_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $topics_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();
                $author = array();

                for ( $i = 1; $i <= $topics_count; $i++ ) {
                    if ( ! empty( $options['topics_content_post_' . $i] ) ) :
                        $post_ids[] = $options['topics_content_post_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $topics_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['topics_content_category'] ) ? $options['topics_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $topics_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;
            
            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();
   
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// topics section content details.
add_filter( 'juju_blog_pro_filter_topics_section_details', 'juju_blog_pro_get_topics_section_details' );


if ( ! function_exists( 'juju_blog_pro_render_topics_section' ) ) :
  /**
   * Start topics section
   *
   * @return string topics content
   * @since Juju Blog Pro 1.0.0
   *
   */
   function juju_blog_pro_render_topics_section( $content_details = array() ) {
        $options = juju_blog_pro_get_theme_options();

        $section_title = !empty( $options['topics_title'] ) ? $options['topics_title'] : '';

        $autoplay = ($options['topics_autoplay']) ? 'true' : 'false';

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="juju_blog_pro_trending_topics_section" class="page-section same-background">
                <div class="wrapper">
                <?php if( !empty( $section_title ) ): ?>
                    <div class="section-header">
                        <h2 class="section-title"><?php echo esc_html( $section_title ); ?></h2>
                    </div><!-- .section-header -->
                <?php endif; ?>

                    <div class="trending-topics-slider" data-slick='{"slidesToShow": 5, "slidesToScroll": 1, "infinite": true, "speed": 800, "dots": true, "arrows":true, "autoplay": <?php echo esc_attr( $autoplay ); ?>, "draggable": true, "fade": false, "adaptiveHeight": true }'>
                        
                    <?php foreach ($content_details as $content ): ?>

                        <article>
                            <div class="featured-images" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                <div class="overlay"></div>
                            </div>
                            <div class="entry-header-wrapper clear">
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>" tabindex="0"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>   
                            </div>
                        </article>
                        
                    <?php endforeach; ?>

                    </div>
                </div><!-- .wrapper -->
            </div>
       
    <?php }
endif;