<?php
/**
 * Event section
 *
 * This is the template for the content of event section
 *
 * @package Theme Palace
 * @subpackage Juju Blog Pro
 * @since Juju Blog Pro 1.0.0
 */
if ( ! function_exists( 'juju_blog_pro_add_upcomming_event_section' ) ) :
    /**
    * Add event section
    *
    *@since Juju Blog Pro 1.0.0
    */
    function juju_blog_pro_add_upcomming_event_section() {
        $options = juju_blog_pro_get_theme_options();
        // Check if event is enabled on frontpage
        $event_enable = apply_filters( 'juju_blog_pro_section_status', true, 'upcomming_event_section_enable' );

        if ( true !== $event_enable ) {
            return false;
        }
        // Get event section details
        $section_details = array();
        $section_details = apply_filters( 'juju_blog_pro_filter_upcomming_event_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render event section now.
        juju_blog_pro_render_upcomming_event_section( $section_details );
    }
endif;

if ( ! function_exists( 'juju_blog_pro_get_upcomming_event_section_details' ) ) :
    /**
    * event section details.
    *
    * @since Juju Blog Pro 1.0.0
    * @param array $input event section details.
    */
    function juju_blog_pro_get_upcomming_event_section_details( $input ) {
        $options = juju_blog_pro_get_theme_options();

        // Content type.
        $upcomming_event_content_type  = $options['upcomming_event_content_type'];
        $upcomming_event_count = ! empty( $options['upcomming_event_count'] ) ? $options['upcomming_event_count'] : 3;

        $content = array();
        switch ( $upcomming_event_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $upcomming_event_count; $i++ ) {
                    if ( ! empty( $options['upcomming_event_content_page_' . $i] ) )
                        $page_ids[] = $options['upcomming_event_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $upcomming_event_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $upcomming_event_count; $i++ ) {
                    if ( ! empty( $options['upcomming_event_content_post_' . $i] ) )
                        $post_ids[] = $options['upcomming_event_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $upcomming_event_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['upcomming_event_content_category'] ) ? $options['upcomming_event_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $upcomming_event_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'event':
                $page_ids = array();

                for ( $i = 1; $i <= $upcomming_event_count; $i++ ) {
                    if ( ! empty( $options['upcomming_event_content_event_' . $i] ) )
                        $page_ids[] = $options['upcomming_event_content_event_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'tp-event',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $upcomming_event_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'event-category':
                $cat_id = ! empty( $options['upcomming_event_content_upcomming_event_category'] ) ? $options['upcomming_event_content_upcomming_event_category'] : '';
                $args = array(
                    'post_type'      => 'tp-event',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'tp-event-category',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $upcomming_event_count ),
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = juju_blog_pro_trim_content( 5 );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-150x150.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// event section content details.
add_filter( 'juju_blog_pro_filter_upcomming_event_section_details', 'juju_blog_pro_get_upcomming_event_section_details' );


if ( ! function_exists( 'juju_blog_pro_render_upcomming_event_section' ) ) :
  /**
   * Start event section
   *
   * @return string event content
   * @since Juju Blog Pro 1.0.0
   *
   */
   function juju_blog_pro_render_upcomming_event_section( $content_details = array() ) {
        $options = juju_blog_pro_get_theme_options();
        $upcomming_event_content_type  = $options['upcomming_event_content_type'];
        $readmore = ! empty( $options['upcomming_event_readmore'] ) ? $options['upcomming_event_readmore'] : esc_html__( 'Buy Ticket', 'juju-blog-pro' );

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="juju_blog_pro_music_event_section" class="relative page-section same-background">
                <div class="wrapper">
                <?php if (! empty( $options['upcomming_event_title'] )): ?>

                    <div class="section-header">
                        <h2 class="section-title"><?php echo esc_html( $options['upcomming_event_title'] ); ?></h2>
                    </div>
                    
                <?php endif; ?>
                    
                    <div class="section-content">
                        
                         <?php foreach ( $content_details as $content ) : 
                        if ( in_array( $upcomming_event_content_type, array( 'event', 'event-category' ) ) && class_exists( 'TP_Education' ) ) :
                            $event_date = get_tp_event_date( $content['id'] );
                            $event_location = get_tp_event_location( $content['id'] );
                            $event_time = get_tp_event_start_time( $content['id'] );
                        endif;
                    ?>


                        <article>
                            <div class="event-item clear">
                                <?php if ( in_array( $upcomming_event_content_type, array( 'event', 'event-category' ) ) && ! empty( $event_date ) ) : ?>
                                    <span class="posted-on">
                                    <?php tp_event_date( $content['id'] ); ?>
                                    </span>
                            <?php endif; ?>

                                <header class="entry-header">
                                    <img src="<?php echo esc_url( $content['image'] ); ?>">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    <?php if ( in_array( $upcomming_event_content_type, array( 'event', 'event-category' ) ) && ! empty( $event_location ) ) : ?>
                                    <p class="location"><?php tp_event_location( $content['id'] ); ?></p>
                                <?php else : ?>
                                    <p class="location"><?php echo esc_html( $content['excerpt'] ); ?></p>
                                <?php endif; ?>
                                </header>

                                <?php if ( in_array( $upcomming_event_content_type, array( 'event', 'event-category' ) ) && ! empty( $event_time ) ) : ?>
                                <span class="event-time"><i class="fa fa-clock-o"></i><?php tp_event_start_time( $content['id'] ); ?></span>
                            <?php endif; ?>

                            <?php if( !empty( $readmore ) ): ?>

                                <div class="buy-ticket">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn"><?php echo esc_html( $readmore ); ?></a>
                                </div><!-- .buy-ticket -->

                            <?php endif; ?>

                            </div><!-- .event-item -->
                        </article>

                        <?php endforeach; ?>

                    </div>

                    <?php if ( ! empty( $options['upcomming_event_btn_title'] ) && ! empty( $options['upcomming_event_btn_link'] ) ) : ?>
                    <div class="read-more">
                        <a href="<?php echo esc_url( $options['upcomming_event_btn_link'] ); ?>" class="btn"><?php echo esc_html( $options['upcomming_event_btn_title'] ); ?></a>
                    </div><!-- .read-more -->
                <?php endif; ?>
                </div>
            </div>

    <?php }
endif;